@@ -297,6 +297,9 @@ adjust_height_for_constraints (FImageView *image_view)
 	} else {
 		GdkPixbuf *pixbuf = image_view_get_pixbuf (IMAGE_VIEW (image_view));
 
+		if (pixbuf == NULL)
+			return FALSE;
+
 		if (*py1 + offset >= gdk_pixbuf_get_height (pixbuf)) {
 			*py2 = gdk_pixbuf_get_height (pixbuf) - 1;
 			g_object_unref (pixbuf);
@@ -341,6 +344,9 @@ adjust_width_for_constraints (FImageView *image_view)
 	} else {
 		GdkPixbuf *pixbuf = image_view_get_pixbuf (IMAGE_VIEW (image_view));
 
+		if (pixbuf == NULL)
+			return FALSE;
+
 		if (*px1 + offset >= gdk_pixbuf_get_width (pixbuf)) {
 			*px2 = gdk_pixbuf_get_width (pixbuf) - 1;
 			g_object_unref (pixbuf);
@@ -363,6 +369,9 @@ constrain_selection (FImageView *image_view)
 
 	if (F_DOUBLE_EQUAL (priv->selection_xy_ratio, 0.0))
 		return;
+	if ((ABS (priv->selection.x2 - priv->selection.x1) > ABS (priv->selection.y2 - priv->selection.y1) && priv->selection_xy_ratio < 1) ||
+		(ABS (priv->selection.x2 - priv->selection.x1) < ABS (priv->selection.y2 - priv->selection.y1) && priv->selection_xy_ratio > 1)) 
+		priv->selection_xy_ratio = (double)1.0 / priv->selection_xy_ratio;
 
 	switch (priv->mode) {
 	case MODE_DRAG_X1:
