@@ -298,7 +298,7 @@ public class Db : IDisposable {
 	public void Init (string path, bool create_if_missing)
 	{
 		bool new_db = ! File.Exists (path);
-		string version_string = "";
+		string version_string = ",version=3";
 		this.path = path;
 
 		if (new_db && ! create_if_missing)
@@ -324,6 +324,7 @@ public class Db : IDisposable {
 
 		sqlite_connection.Open ();
 		
+
 		// Load or create the meta table
  		meta_store = new MetaStore (sqlite_connection, new_db);
 
@@ -352,14 +353,27 @@ public class Db : IDisposable {
 
 
 public class DbUtils {
+#if USE_CORRECT_FUNCTION
+	public static DateTime DateTimeFromUnixTime (long unix_time)
+	{
+		DateTime date_time = new DateTime (1970, 1, 1);
+		return date_time.AddSeconds (unix_time).ToLocalTime ();
+	}
+
+	public static long UnixTimeFromDateTime (DateTime date_time)
+	{
+		return (long) (date_time.ToUniversalTime () - new DateTime (1970, 1, 1)).TotalSeconds;
+	}
+#else
 	public static DateTime DateTimeFromUnixTime (long unix_time)
 	{
 		DateTime date_time = new DateTime (1970, 1, 1).ToLocalTime ();
 		return date_time.AddSeconds (unix_time);
 	}
-
+	
 	public static long UnixTimeFromDateTime (DateTime date_time)
 	{
 		return (long) (date_time - new DateTime (1970, 1, 1).ToLocalTime ()).TotalSeconds;
 	}
+#endif
 }
