@@ -23,7 +23,7 @@ using System;
 using System.IO;
 using System.Runtime.InteropServices;
 
-using Mono.Posix;
+using Mono.Unix;
 
 using ICSharpCode.SharpZipLib.Checksums;
 using ICSharpCode.SharpZipLib.Zip;
@@ -106,7 +106,7 @@ namespace FSpot {
 			if (!System.IO.Directory.Exists (uri_path))
 			        uri_path = FSpot.Global.HomeDirectory;
 
-			uri_chooser = new Gtk.FileChooserButton (Mono.Posix.Catalog.GetString ("Select Export Folder"),
+			uri_chooser = new Gtk.FileChooserButton (Catalog.GetString ("Select Export Folder"),
 								 Gtk.FileChooserAction.SelectFolder);
 			uri_chooser.SetFilename (uri_path);
 			uri_chooser.LocalOnly = false;
@@ -116,6 +116,12 @@ namespace FSpot {
 
 			//LoadHistory ();
 			Dialog.Response += HandleResponse;
+
+			LoadPreference (Preferences.EXPORT_FOLDER_SCALE);
+			LoadPreference (Preferences.EXPORT_FOLDER_SIZE);
+			LoadPreference (Preferences.EXPORT_FOLDER_OPEN);
+			LoadPreference (Preferences.EXPORT_FOLDER_ROTATE);
+			LoadPreference (Preferences.EXPORT_FOLDER_METHOD);
 		}
 
 		public void HandleSizeActive (object sender, System.EventArgs args)
@@ -139,7 +145,7 @@ namespace FSpot {
 				if (dest.IsLocal)
 					gallery_path = Gnome.Vfs.Uri.GetLocalPathFromUri (dest.ToString ());
 
-				progress_dialog.Message = Mono.Posix.Catalog.GetString ("Building Gallery");
+				progress_dialog.Message = Catalog.GetString ("Building Gallery");
 				progress_dialog.Fraction = 1.0;
 
 				FolderGallery gallery;
@@ -182,22 +188,30 @@ namespace FSpot {
 
 				if (result == Gnome.Vfs.Result.Ok) {
 
-					progress_dialog.Message = Mono.Posix.Catalog.GetString ("Done Sending Photos");
+					progress_dialog.Message = Catalog.GetString ("Done Sending Photos");
 					progress_dialog.Fraction = 1.0;
-					progress_dialog.ProgressText = Mono.Posix.Catalog.GetString ("Transfer Complete");
+					progress_dialog.ProgressText = Catalog.GetString ("Transfer Complete");
 					progress_dialog.ButtonLabel = Gtk.Stock.Ok;
 
 				} else {
 					progress_dialog.ProgressText = result.ToString ();
-					progress_dialog.Message = Mono.Posix.Catalog.GetString ("Error While Transferring");
+					progress_dialog.Message = Catalog.GetString ("Error While Transferring");
 				}
 
 				if (open) {
 					GnomeUtil.UrlShow (null, target.ToString ());
 				}
+
+				// Save these settings for next time
+				Preferences.Set (Preferences.EXPORT_FOLDER_SCALE, scale);
+				Preferences.Set (Preferences.EXPORT_FOLDER_SIZE, size);
+				Preferences.Set (Preferences.EXPORT_FOLDER_OPEN, open);
+				Preferences.Set (Preferences.EXPORT_FOLDER_ROTATE, rotate);
+				Preferences.Set (Preferences.EXPORT_FOLDER_METHOD, static_radio.Active ? "static" : original_radio.Active ? "original" : "folder" );
+
 			} catch (System.Exception e) {
 				progress_dialog.Message = e.ToString ();
-				progress_dialog.ProgressText = Mono.Posix.Catalog.GetString ("Error Transferring");
+				progress_dialog.ProgressText = Catalog.GetString ("Error Transferring");
 			} finally {
 				// if the destination isn't local then we want to remove the temp directory we
 				// created.
@@ -205,6 +219,7 @@ namespace FSpot {
 					System.IO.Directory.Delete (gallery_path, true);
 				
 				Gtk.Application.Invoke (delegate { Dialog.Destroy(); });
+
 			}
 		}
 
@@ -218,10 +233,10 @@ namespace FSpot {
 			
 			switch (info.Status) {
 			case Gnome.Vfs.XferProgressStatus.Vfserror:
-				progress_dialog.Message = Mono.Posix.Catalog.GetString ("Error: Error while transferring; Aborting");
+				progress_dialog.Message = Catalog.GetString ("Error: Error while transferring; Aborting");
 				return (int)Gnome.Vfs.XferErrorAction.Abort;
 			case Gnome.Vfs.XferProgressStatus.Overwrite:
-				progress_dialog.ProgressText = Mono.Posix.Catalog.GetString ("Error: File Already Exists; Aborting");
+				progress_dialog.ProgressText = Catalog.GetString ("Error: File Already Exists; Aborting");
 				return (int)Gnome.Vfs.XferOverwriteAction.Abort;
 			default:
 				return 1;
@@ -275,7 +290,7 @@ namespace FSpot {
 				size = size_spin.ValueAsInt;
 
 			command_thread = new System.Threading.Thread (new System.Threading.ThreadStart (Upload));
-			command_thread.Name = Mono.Posix.Catalog.GetString ("Transferring Pictures");
+			command_thread.Name = Catalog.GetString ("Transferring Pictures");
 
 			//FIXME: get the files/dirs count in a cleaner way than (* 5 + 2(zip) + 9)
 			// selection * 5 (original, mq, lq, thumbs, comments)
@@ -285,6 +300,42 @@ namespace FSpot {
 			progress_dialog = new FSpot.ThreadProgressDialog (command_thread, 1);
 			progress_dialog.Start ();
 		}
+
+		void LoadPreference (string key)
+		{
+			object val = Preferences.Get (key);
+
+			if (val == null)
+				return;
+			
+			//System.Console.WriteLine ("Setting {0} to {1}", key, val);
+
+			switch (key) {
+			case Preferences.EXPORT_FOLDER_SCALE:
+				if (scale_check.Active != (bool) val)
+					scale_check.Active = (bool) val;
+				break;
+
+			case Preferences.EXPORT_FOLDER_SIZE:
+				size_spin.Value = (double) (int) val;
+				break;
+			
+			case Preferences.EXPORT_FOLDER_OPEN:
+				if (open_check.Active != (bool) val)
+					open_check.Active = (bool) val;
+				break;
+			
+			case Preferences.EXPORT_FOLDER_ROTATE:
+				if (rotate_check.Active != (bool) val)
+					rotate_check.Active = (bool) val;
+				break;
+			case Preferences.EXPORT_FOLDER_METHOD:
+				static_radio.Active = (string) val == "static";
+				original_radio.Active = (string) val == "original";
+				plain_radio.Active = (string) val == "folder";
+				break;
+			}
+		}
 	}
 
 	internal class FolderGallery 
@@ -613,8 +664,8 @@ namespace FSpot {
 		string altstylesheet = "f-spot-simple-white.css";
 		string javascript = "f-spot.js";
 
-        static string light = Mono.Posix.Catalog.GetString("Light");
-        static string dark = Mono.Posix.Catalog.GetString("Dark");
+        static string light = Catalog.GetString("Light");
+        static string dark = Catalog.GetString("Dark");
 		
 		public HtmlGallery (IBrowsableCollection selection, string path, string name) : base (selection, path, name) 
 		{ 
@@ -754,12 +805,12 @@ namespace FSpot {
 
 			if (i > 0)
 				// Abbreviation of previous	
-				WritePageNav (writer, "prev", PhotoIndexPath (i - 1), Mono.Posix.Catalog.GetString("Prev"));
+				WritePageNav (writer, "prev", PhotoIndexPath (i - 1), Catalog.GetString("Prev"));
 
-			WritePageNav (writer, "index", IndexPath (i / perpage), Mono.Posix.Catalog.GetString("Index"));
+			WritePageNav (writer, "index", IndexPath (i / perpage), Catalog.GetString("Index"));
 			
 			if (i < collection.Count -1)
-				WritePageNav (writer, "next", PhotoIndexPath (i + 1), Mono.Posix.Catalog.GetString("Next"));
+				WritePageNav (writer, "next", PhotoIndexPath (i + 1), Catalog.GetString("Next"));
 
 			writer.RenderEndTag (); //navi
 			
@@ -870,7 +921,7 @@ namespace FSpot {
 			writer.AddAttribute ("class", "footer");
 			writer.RenderBeginTag ("div");
 			
-			writer.Write (Mono.Posix.Catalog.GetString ("Gallery generated by") + " ");
+			writer.Write (Catalog.GetString ("Gallery generated by") + " ");
 			
 			writer.AddAttribute ("href", "http://www.gnome.org/projects/f-spot");
 			writer.RenderBeginTag ("a");
@@ -915,7 +966,7 @@ namespace FSpot {
 
 			writer.AddAttribute ("class", "navilabel");
 			writer.RenderBeginTag ("div");
-			writer.Write (Mono.Posix.Catalog.GetString ("Page:"));
+			writer.Write (Catalog.GetString ("Page:"));
 			writer.RenderEndTag (); //pages div
 			
 			int i;
@@ -985,8 +1036,8 @@ namespace FSpot {
 			writer.RenderBeginTag ("div");
 			writer.Write ("<span class=\"style_toggle\">"); 
 			writer.Write ("<a href=\"javascript:toggle_stylebox()\">");
-			writer.Write ("<span id=\"showlink\">" + Mono.Posix.Catalog.GetString("Show Styles") + "</span><span id=\"hidelink\" ");
-			writer.Write ("style=\"display:none;\">" + Mono.Posix.Catalog.GetString("Hide Styles") + "</span></a></span>\n");
+			writer.Write ("<span id=\"showlink\">" + Catalog.GetString("Show Styles") + "</span><span id=\"hidelink\" ");
+			writer.Write ("style=\"display:none;\">" + Catalog.GetString("Hide Styles") + "</span></a></span>\n");
 			writer.RenderEndTag (); //div toggle
 			writer.RenderEndTag (); //div styleboxcontainer
 			writer.RenderEndTag (); //container1
