@@ -541,7 +541,7 @@ namespace FSpot {
 	public class GalleryExport : GladeDialog {
 		public GalleryExport (IBrowsableCollection selection) : base ("gallery_export_dialog")
 		{
-			this.photos = (Photo []) selection.Items;
+			this.items = selection.Items;
 			album_button.Sensitive = false;
 			IconView view = new IconView (selection);
 			view.DisplayDates = false;
@@ -562,7 +562,6 @@ namespace FSpot {
 			if (edit_button != null)
 				edit_button.Clicked += HandleEditGallery;
 			
-			rh = new Gtk.ResponseHandler (HandleResponse);
 			Dialog.Response += HandleResponse;
 			connect = true;
 			HandleSizeActive (null, null);
@@ -575,8 +574,6 @@ namespace FSpot {
 			LoadPreference (Preferences.EXPORT_GALLERY_ROTATE);
 		}
 		
-		Gtk.ResponseHandler rh;
-		
 		private bool scale;
 		private bool rotate;
 		private int size;
@@ -584,7 +581,7 @@ namespace FSpot {
 		private bool meta;
 		private bool connect = false;
 
-		Photo [] photos;
+		IBrowsableItem[] items;
 		int photo_index;
 		FSpot.ThreadProgressDialog progress_dialog;
 		
@@ -594,10 +591,6 @@ namespace FSpot {
 
 		private string xml_path;
 
-		// Dialogs
-		private AccountDialog gallery_add;
-		private GalleryAddAlbum album_add;
-
 		// Widgets
 		[Glade.Widget] Gtk.OptionMenu gallery_optionmenu;
 		[Glade.Widget] Gtk.OptionMenu album_optionmenu;
@@ -651,7 +644,7 @@ namespace FSpot {
 				command_thread = new System.Threading.Thread (new System.Threading.ThreadStart (this.Upload));
 				command_thread.Name = Catalog.GetString ("Uploading Pictures");
 				
-				progress_dialog = new FSpot.ThreadProgressDialog (command_thread, photos.Length);
+				progress_dialog = new FSpot.ThreadProgressDialog (command_thread, items.Length);
 				progress_dialog.Start ();
 
 				// Save these settings for next time
@@ -666,7 +659,7 @@ namespace FSpot {
 		private void HandleProgressChanged (ProgressItem item)
 		{
 			//System.Console.WriteLine ("Changed value = {0}", item.Value);
-			progress_dialog.Fraction = (photo_index - 1.0 + item.Value) / (double) photos.Length;
+			progress_dialog.Fraction = (photo_index - 1.0 + item.Value) / (double) items.Length;
 		}
 
 		public void HandleSizeActive (object sender, EventArgs args)
@@ -689,19 +682,19 @@ namespace FSpot {
 					filters.Add (new OrientationFilter ());
 				
 
-				while (photo_index < photos.Length) {
-					Photo photo = photos [photo_index];
+				while (photo_index < items.Length) {
+					IBrowsableItem item = items [photo_index];
 
 					System.Console.WriteLine ("uploading {0}", photo_index);
 
-					progress_dialog.Message = System.String.Format (Catalog.GetString ("Uploading picture \"{0}\""), photo.Name);
-					progress_dialog.Fraction = photo_index / (double) photos.Length;
+					progress_dialog.Message = System.String.Format (Catalog.GetString ("Uploading picture \"{0}\""), item.Name);
+					progress_dialog.Fraction = photo_index / (double) items.Length;
 					photo_index++;
 
-					progress_dialog.ProgressText = System.String.Format (Catalog.GetString ("{0} of {1}"), photo_index, photos.Length);
+					progress_dialog.ProgressText = System.String.Format (Catalog.GetString ("{0} of {1}"), photo_index, items.Length);
 					
 					
-					string orig = photo.DefaultVersionUri.LocalPath;
+					string orig = item.DefaultVersionUri.LocalPath;
 
 					// FIXME the filters need to be able to handle entension
 					// changes directly themselves.
@@ -711,8 +704,10 @@ namespace FSpot {
 					else if (rotate)
 						final = ImageFile.TempPath (orig);
 					
-					bool changed = filters.Convert (orig, final);
-					album.Add (photo, final);
+					if (filters.Convert (orig, final))
+						album.Add (item, final);
+					else
+						album.Add (item, orig);
 					
 					if (final != orig)
 						System.IO.File.Delete (final);
@@ -793,12 +788,7 @@ namespace FSpot {
 				PopulateAlbumOptionMenu (account.Gallery);
 				album_button.Sensitive = false;
 				
-				AccountDialog dialog = new AccountDialog (this.Dialog, account, true);
-				Gtk.ResponseType response = (Gtk.ResponseType) dialog.Dialog.Run ();
-
-				if (response == Gtk.ResponseType.Ok) {
-					Connect (account);					
-				}
+				new AccountDialog (this.Dialog, account, true);
 			} 
 		}
 
@@ -865,7 +855,7 @@ namespace FSpot {
 						item.Sensitive = false;
 				}
 
-				ok_button.Sensitive = photos.Length > 0;
+				ok_button.Sensitive = items.Length > 0;
 				album_optionmenu.Sensitive = true;
 				album_button.Sensitive = true;
 			}
@@ -876,12 +866,12 @@ namespace FSpot {
 		
 		public void HandleAddGallery (object sender, System.EventArgs args)
 		{
-			gallery_add = new AccountDialog (this.Dialog);
+			new AccountDialog (this.Dialog);
 		}
 		
 		public void HandleEditGallery (object sender, System.EventArgs args)
 		{
-			gallery_add = new AccountDialog (this.Dialog, account, false);
+			new AccountDialog (this.Dialog, account, false);
 		}
 
 		public void HandleAddAlbum (object sender, System.EventArgs args)
@@ -889,7 +879,7 @@ namespace FSpot {
 			if (account == null)
 				throw new Exception (Catalog.GetString ("No account selected"));
 				
-			album_add = new GalleryAddAlbum (this, account.Gallery);
+			new GalleryAddAlbum (this, account.Gallery);
 		}
 
 		void LoadPreference (string key)
