@@ -36,7 +36,6 @@ namespace GalleryRemote {
 		Gallery gallery;
 		
 		public AlbumPermission Perms = AlbumPermission.None;
-		Hashtable extras = null;
 
 		public Album Parent {
 			get {
@@ -77,20 +76,20 @@ namespace GalleryRemote {
 			gallery.MoveAlbum (this, name);
 		}
 
-		public void Add (Photo photo) 
+		public void Add (FSpot.IBrowsableItem item) 
 		{
-			Add (photo, photo.DefaultVersionUri.LocalPath);
+			Add (item, item.DefaultVersionUri.LocalPath);
 		}
 
-		public void Add (Photo photo, string path)		
+		public void Add (FSpot.IBrowsableItem item, string path)		
 		{
-			if (photo == null)
+			if (item == null)
 				Console.WriteLine ("NO PHOTO");
 			
 			gallery.AddItem (this, 
 					 path,
-					 Path.GetFileName (photo.DefaultVersionUri.LocalPath),
-					 photo.Description, 
+					 Path.GetFileName (item.DefaultVersionUri.LocalPath),
+					 item.Description, 
 					 true);
 		}
 		
@@ -291,13 +290,12 @@ namespace GalleryRemote {
 					client.Submit (new Uri (Gallery.FixUrl (url, Gallery1.script_name)));
 					version =  GalleryVersion.Version1;
 
-				} catch (System.Net.WebException e) {
-
+				} catch (System.Net.WebException) {
 					try {
 						client.Submit (new Uri (Gallery.FixUrl (url, Gallery2.script_name)));
 						version =  GalleryVersion.Version2;
 
-					} catch (System.Net.WebException e2) {
+					} catch (System.Net.WebException) {
 						//Uh oh, neither version detected
 						version = GalleryVersion.VersionUnknown;
 					}
@@ -454,7 +452,7 @@ namespace GalleryRemote {
 						//G1 FetchAlbumsPrune returns album names (and 0 for root albums)
 						try {
 							current_album.ParentRefNum = int.Parse (data[1]);
-						} catch (System.FormatException e) {
+						} catch (System.FormatException) {
 							current_album.ParentRefNum = LookupAlbum (data[1]).RefNum;
 						}
 						//Console.WriteLine ("album.parent data[1]: " + data[1]);
@@ -798,7 +796,7 @@ namespace GalleryRemote {
 					} else if (data[0].StartsWith ("image.clicks")) {
 						try {
 							current_image.Clicks = int.Parse (data[1]);
-						} catch (System.FormatException e) {
+						} catch (System.FormatException) {
 							current_image.Clicks = 0;
 						}
 					} else if (data[0].StartsWith ("baseurl")) {
@@ -838,12 +836,9 @@ namespace GalleryRemote {
 			url = url.Remove (url.Length - script_name.Length, script_name.Length); 
 
 			string path = album.Name;
-			while (album.Parent != null) {
-				album = album.Parent;
-				path = album.Name + "/" + path;
-			}	
+
 			url = url + path;
-			url = url.Replace (" ", "%20");
+			url = url.Replace (" ", "+");
 			return url;
 		}
 
@@ -1034,7 +1029,7 @@ namespace GalleryRemote {
 					} else if (data[0].StartsWith ("image.clicks")) {
 						try {
 							current_image.Clicks = int.Parse (data[1]);
-						} catch (System.FormatException e) {
+						} catch (System.FormatException) {
 							current_image.Clicks = 0;
 						}
 					} else if (data[0].StartsWith ("baseurl")) {
