@@ -113,6 +113,17 @@ public class IconView : Gtk.Layout {
 		}
 	}
 
+	private bool display_filenames = false;
+	public bool DisplayFilenames {
+		get { return display_filenames; }
+		set {
+			if (value != display_filenames) {
+				display_filenames = value;
+				QueueResize ();
+			}
+		}
+	}
+
 	// Size of the frame around the thumbnail.
 	protected int cell_border_width = 10;
 
@@ -128,7 +139,7 @@ public class IconView : Gtk.Layout {
 	// Horizontal spacing between the tag icons
 	protected int tag_icon_hspacing = 2;
 
-	// Vertical spacing between the thumbnail and the row of tag icons.
+	// Vertical spacing between the thumbnail and additional infos (tags, dates, ...).
 	protected int tag_icon_vspacing = 3;
 
 	// Various other layout values.
@@ -142,9 +153,6 @@ public class IconView : Gtk.Layout {
 	private int y_offset;
 	private int x_offset;
 
-	// Drag and drop bookkeeping. 
-	private int click_x, click_y;
-
 	// Focus Handling
 	private int real_focus_cell;
 	public int FocusCell {
@@ -629,8 +637,11 @@ public class IconView : Gtk.Layout {
 		cells_per_row = Math.Max ((int) (available_width / cell_width), 1);
 		cell_width += (available_width - cells_per_row * cell_width) / cells_per_row;
 		
+		if (DisplayTags || DisplayDates || DisplayFilenames)
+			cell_height += tag_icon_vspacing;
+
 		if (DisplayTags)
-			cell_height += tag_icon_size + tag_icon_vspacing;
+			cell_height += tag_icon_size;
 		
 		if (DisplayDates && this.Style != null) {
 			Pango.FontMetrics metrics = this.PangoContext.GetMetrics (this.Style.FontDescription, 
@@ -638,6 +649,12 @@ public class IconView : Gtk.Layout {
 			cell_height += PangoPixels (metrics.Ascent + metrics.Descent);
 		}
 
+		if (DisplayFilenames && this.Style != null) {
+			Pango.FontMetrics metrics = this.PangoContext.GetMetrics (this.Style.FontDescription,
+										Pango.Language.FromString ("en_US"));
+			cell_height += PangoPixels (metrics.Ascent + metrics.Descent);
+		}
+
 		int num_thumbnails;
 		if (collection != null)
 			num_thumbnails = collection.Count;
@@ -788,11 +805,9 @@ public class IconView : Gtk.Layout {
 									      
 					
 					lock (entry) {
-						if (entry.Reload && expansion == 0) {
-							if (entry.Path != null) {
-								entry.Pixbuf = PixbufUtils.ShallowCopy (temp_thumbnail);
-								entry.Reload = true;
-							}
+						if (entry.Reload && expansion == 0 && !entry.IsDisposed) {
+							entry.SetPixbufExtended (PixbufUtils.ShallowCopy (temp_thumbnail), false);
+							entry.Reload = true;
 						}
 					}
 				} else {
@@ -856,7 +871,35 @@ public class IconView : Gtk.Layout {
 			
 			layout.GetPixelSize (out layout_bounds.Width, out layout_bounds.Height);
 
-			layout_bounds.Y = bounds.Y + bounds.Height - cell_border_width - layout_bounds.Height;
+			layout_bounds.Y = bounds.Y + bounds.Height - cell_border_width - layout_bounds.Height + tag_icon_vspacing;
+			layout_bounds.X = bounds.X + (bounds.Width - layout_bounds.Width) / 2;
+			
+			if (DisplayTags)
+				layout_bounds.Y -= tag_icon_size;
+
+			if (DisplayFilenames) {
+				Pango.FontMetrics metrics = this.PangoContext.GetMetrics (this.Style.FontDescription,
+						Pango.Language.FromString ("en_US"));
+				layout_bounds.Y -= PangoPixels (metrics.Ascent + metrics.Descent); 
+			}
+
+			if (layout_bounds.Intersect (area, out region)) {
+				Style.PaintLayout (Style, BinWindow, cell_state,
+						   true, area, this, "IconView", 
+						   layout_bounds.X, layout_bounds.Y, 
+						   layout);
+			}
+		}
+
+		if (DisplayFilenames) {
+
+			string filename = System.IO.Path.GetFileName (photo.DefaultVersionUri.LocalPath);
+			Pango.Layout layout = new Pango.Layout (this.PangoContext);
+			layout.SetText (filename);
+			
+			layout.GetPixelSize (out layout_bounds.Width, out layout_bounds.Height);
+
+			layout_bounds.Y = bounds.Y + bounds.Height - cell_border_width - layout_bounds.Height + tag_icon_vspacing;
 			layout_bounds.X = bounds.X + (bounds.Width - layout_bounds.Width) / 2;
 			
 			if (DisplayTags)
@@ -868,14 +911,15 @@ public class IconView : Gtk.Layout {
 						   layout_bounds.X, layout_bounds.Y, 
 						   layout);
 			}
+			
 		}
 
 		if (DisplayTags) {
 			Tag [] tags = photo.Tags;
 			Gdk.Rectangle tag_bounds;
 
-			tag_bounds.X = bounds.X + (bounds.Width  + tag_icon_vspacing - tags.Length * (tag_icon_size + tag_icon_vspacing)) / 2;
-			tag_bounds.Y = bounds.Y + bounds.Height - cell_border_width - tag_icon_size;
+			tag_bounds.X = bounds.X + (bounds.Width  + tag_icon_hspacing - tags.Length * (tag_icon_size + tag_icon_hspacing)) / 2;
+			tag_bounds.Y = bounds.Y + bounds.Height - cell_border_width - tag_icon_size + tag_icon_vspacing;
 			tag_bounds.Width = tag_icon_size;
 			tag_bounds.Height = tag_icon_size;
 			
@@ -883,18 +927,17 @@ public class IconView : Gtk.Layout {
 				if (t == null)
 					continue;
 
-				Pixbuf icon = null;
-				if (t.Category.Icon == null) {
-					if (t.Icon == null)
-						continue;
-					icon = t.Icon;
-				} else {
-					Category category = t.Category;
-					while (category.Category.Icon != null)
-						category = category.Category;
-					icon = category.Icon;
-				}
+				Pixbuf icon = t.Icon;
 
+		                Tag tag_iter = t.Category;
+		                while (icon == null && tag_iter != Core.Database.Tags.RootCategory && tag_iter != null) {
+		                    icon = tag_iter.Icon;
+		                    tag_iter = tag_iter.Category;
+		                }
+		
+		                if (icon == null)
+		                    continue;
+		
 				if (tag_bounds.Intersect (area, out region)) {
 					Pixbuf scaled_icon;
 					if (icon.Width == tag_bounds.Width) {
@@ -915,9 +958,10 @@ public class IconView : Gtk.Layout {
 						scaled_icon.Dispose ();
 					}
 				}
-				tag_bounds.X += tag_bounds.Width + tag_icon_vspacing;
+				tag_bounds.X += tag_bounds.Width + tag_icon_hspacing;
 			}
 		}
+
 	}
 
 	private void DrawAllCells (Gdk.Rectangle area)
@@ -1192,7 +1236,7 @@ public class IconView : Gtk.Layout {
 		Gdk.Pixbuf result = entry.ShallowCopyPixbuf ();
 		int order = (int) entry.Data;
 
-		if (order > 0 && order < collection.Count) {
+		if (order >= 0 && order < collection.Count) {
 			System.Uri uri = collection [order].DefaultVersionUri;
 
 			if (result == null && !System.IO.File.Exists (FSpot.ThumbnailGenerator.ThumbnailPath (uri)))
@@ -1366,9 +1410,6 @@ public class IconView : Gtk.Layout {
 			if (args.Event.Button != 1)
 				return;
 
-			click_x = (int) args.Event.X;
-			click_y = (int) args.Event.Y;
-
 			FocusCell = cell_num;
 			return;
 
