@@ -4,6 +4,10 @@ using System.IO;
 using FSpot.Xmp;
 using FSpot.Tiff;
 
+#if ENABLE_NUNIT
+using NUnit.Framework;
+#endif
+
 namespace FSpot {
 	public interface IThumbnailContainer {
 		Gdk.Pixbuf GetEmbeddedThumbnail ();
@@ -23,7 +27,7 @@ namespace FSpot {
 		public JpegFile (Uri uri) : base (uri)
 		{
 			try {
-				System.Console.WriteLine ("approximate quality = {0}", Header.GuessQuality ());
+				// Console.WriteLine ("approximate quality = {0}", Header.GuessQuality ());
 			} catch (Exception e) {
 				System.Console.WriteLine (e);
 			}
@@ -124,12 +128,14 @@ namespace FSpot {
 			JpegHeader header = new JpegHeader (input);
 			UpdateMeta ();
 			
+			// Console.WriteLine ("updated metadata");
 			header.SetExif (this.ExifData);
-
+			// Console.WriteLine ("set exif");
 			if (xmp != null)
 				header.SetXmp (xmp);
-
+			// Console.WriteLine ("set xmp");
 			header.Save (output);
+			// Console.WriteLine ("saved");
 		}
 		
 		public void SaveMetaData (string path)
@@ -160,7 +166,7 @@ namespace FSpot {
 			Gdk.Pixbuf thumbnail = PixbufUtils.ScaleToAspect (source, 160, 120);
 			byte [] thumb_data = PixbufUtils.Save (thumbnail, "jpeg", null, null);
 			
-			System.Console.WriteLine ("saving thumbnail");				
+			// System.Console.WriteLine ("saving thumbnail");				
 
 			// now update the exif data
 			ExifData.Data = thumb_data;
@@ -192,18 +198,22 @@ namespace FSpot {
 
 		public override void Save (Gdk.Pixbuf pixbuf, System.IO.Stream stream)
 		{
+
+			// Console.WriteLine ("starting save");
 			// First save the imagedata
 			byte [] image_data = PixbufUtils.Save (pixbuf, "jpeg", null, null);
 			System.IO.MemoryStream buffer = new System.IO.MemoryStream ();
 			buffer.Write (image_data, 0, image_data.Length);
 			buffer.Position = 0;
 			
+			// Console.WriteLine ("setting thumbnail");
 			SetThumbnail (pixbuf);
 			SetDimensions (pixbuf.Width, pixbuf.Height);
 			pixbuf.Dispose ();
-
+			
+			// Console.WriteLine ("saving metatdata");
 			SaveMetaData (buffer, stream);
-
+			// Console.WriteLine ("done");
 			buffer.Close ();
 		}
 		
@@ -228,10 +238,10 @@ namespace FSpot {
 				if (exif_data == null) {
 					exif_data = Header.Exif;
 
-					if (exif_data.Handle.Handle == System.IntPtr.Zero)
+					if (exif_data == null || exif_data.Handle.Handle == System.IntPtr.Zero)
 						exif_data = new Exif.ExifData ();
 				}
-				System.Console.WriteLine ("loading exif data");
+				// System.Console.WriteLine ("loading exif data");
 				return exif_data;
 			}
 			set {
@@ -266,7 +276,7 @@ namespace FSpot {
 		public void SetOrientation (PixbufOrientation orientation)
 		{
 			Exif.ExifEntry e = this.ExifData.GetContents (Exif.Ifd.Zero).GetEntry (Exif.Tag.Orientation);
-			System.Console.WriteLine ("Saving orientation as {0}", orientation);
+			// System.Console.WriteLine ("Saving orientation as {0}", orientation);
 			e.SetData ((ushort)orientation);
 		       
 			e = this.ExifData.GetContents (Exif.Ifd.One).Lookup (Exif.Tag.Orientation);
@@ -318,6 +328,49 @@ namespace FSpot {
 				return time;
 			}
 		}
-		
+
+#if ENABLE_NUNIT
+		[TestFixture]
+		public class Tests {
+			public Tests ()
+			{
+				Gnome.Vfs.Vfs.Initialize ();
+				Gtk.Application.Init ();
+			}
+			
+#if false
+			[Test]
+			public void TestLoad ()
+			{
+				JpegFile jimg = new JpegFile ("/home/lewing/start.swe.jpeg");
+				Assert.AreEqual (PixbufOrientation.TopLeft, jimg.Orientation);
+			}
+#endif
+			[Test]
+			public void TestSave ()
+			{
+				string desc = "this is an example description";
+				string desc2 = "\x00a9 Novell Inc.";
+				PixbufOrientation orient = PixbufOrientation.TopRight;
+				Gdk.Pixbuf test = new Gdk.Pixbuf (null, "f-spot-32.png");
+				string path = ImageFile.TempPath ("joe.jpg");
+				
+				PixbufUtils.SaveJpeg (test, path, 75, new Exif.ExifData ());
+				JpegFile jimg = new JpegFile (path);
+				jimg.SetDescription (desc);
+				jimg.SetOrientation (orient);
+				jimg.SaveMetaData (path);
+				JpegFile mod = new JpegFile (path);
+				Assert.AreEqual (mod.Orientation, orient);
+				Assert.AreEqual (mod.Description, desc);
+				jimg.SetDescription (desc2);
+				jimg.SaveMetaData (path);
+				mod = new JpegFile (path);
+				Assert.AreEqual (mod.Description, desc2);
+				
+				File.Delete (path);
+			}
+		}
+#endif
 	}
 }
