@@ -19,7 +19,13 @@
 
 using System;
 using System.IO;
+using System.Collections;
 using FSpot.Xmp;
+using FSpot;
+
+#if ENABLE_NUNIT
+using NUnit.Framework;
+#endif
 
 public class JpegHeader : SemWeb.StatementSource {
 	public enum JpegMarker {
@@ -108,6 +114,12 @@ public class JpegHeader : SemWeb.StatementSource {
 	private System.Collections.ArrayList marker_list = new System.Collections.ArrayList ();	
 	private byte [] image_data;
 
+                // False seems a safe default
+                public bool Distinct {
+                        get { return false; }
+                }
+
+
 	public class Marker {
 		public JpegMarker Type;
 		public byte [] Data;
@@ -182,7 +194,7 @@ public class JpegHeader : SemWeb.StatementSource {
 			// FIXME there is a potential loop here.
 			
 			int read = Read (stream, raw, 0, 2);
-			if (read < 2 && raw [0] != 0xff)
+			if (read < 2 || raw [0] != 0xff)
 				throw new System.Exception (System.String.Format ("Invalid marker found {0}", raw [0]));
 			
 			JpegMarker id = (JpegMarker) raw [1];
@@ -389,10 +401,13 @@ public class JpegHeader : SemWeb.StatementSource {
 
 	public void SetExif (Exif.ExifData value)
 	{
+		// Console.WriteLine ("before save");
 		byte [] raw_data = value.Save ();
+		// Console.WriteLine ("saved");
 		Marker exif = new Marker (ExifSignature.Id, raw_data);
-
+		// Console.WriteLine ("new");
 		Replace (ExifSignature, exif);
+		// Console.WriteLine ("replaced");
 	}	
 	
 	public void SetXmp (XmpFile xmp)
@@ -416,8 +431,8 @@ public class JpegHeader : SemWeb.StatementSource {
 	public void Save (System.IO.Stream stream)
 	{
 		foreach (Marker marker in marker_list) {
-			//System.Console.WriteLine ("saving marker {0} {1}", marker.Type, 
-			//			   (marker.Data != null) ? marker.Data.Length .ToString (): "(null)");
+			// System.Console.WriteLine ("saving marker {0} {1}", marker.Type, 
+			//			  (marker.Data != null) ? marker.Data.Length .ToString (): "(null)");
 			marker.Save (stream);
 			if (marker.Type == JpegMarker.Sos)
 				stream.Write (ImageData, 0, ImageData.Length);
@@ -451,7 +466,7 @@ public class JpegHeader : SemWeb.StatementSource {
 			if (marker == null)
 				break;
 
-			//System.Console.WriteLine ("loaded marker {0} length {1}", marker.Type, marker.Data.Length);
+			// System.Console.WriteLine ("loaded marker {0} length {1}", marker.Type, marker.Data.Length);
 
 			this.Markers.Add (marker);
 			
@@ -459,7 +474,7 @@ public class JpegHeader : SemWeb.StatementSource {
 				at_image = true;
 
 				if (metadata_only) {
-					System.Console.WriteLine ("read = {0}", stream.Position);
+					// System.Console.WriteLine ("read = {0}", stream.Position);
 					return;
 				}
 			}
@@ -483,7 +498,7 @@ public class JpegHeader : SemWeb.StatementSource {
 		121, 112, 100, 120,  92, 101, 103,  99
 	};
 
-	static int [] StandardChromninaceQuantization = new int [] {
+	static int [] StandardChrominanceQuantization = new int [] {
 		17,  18,  18,  24,  21,  24,  47,  26,
 		26,  47,  99,  66,  56,  66,  99,  99,
 		99,  99,  99,  99,  99,  99,  99,  99,
@@ -517,11 +532,11 @@ public class JpegHeader : SemWeb.StatementSource {
 			tableindex = dqt.Data [position ++];
 
 			switch (tableindex & 0x0f) {
-			case 1:
+			case 0:
 				table = StandardLuminanceQuantization;
 				break;
-			case 2:
-				table = StandardChromninaceQuantization;
+			case 1:
+				table = StandardChrominanceQuantization;
 				break;
 			default:
 				table = null;
@@ -580,6 +595,101 @@ public class JpegHeader : SemWeb.StatementSource {
 			return image_data;
 		}
 	}
+
+#if ENABLE_NUNIT
+	[TestFixture]
+	public class Tests {
+		int quality =  75;
+
+		public string CreateFile ()
+		{
+			Gdk.Pixbuf test = new Gdk.Pixbuf (null, "f-spot-32.png");
+			string path = FSpot.ImageFile.TempPath ("joe.jpg");
+			string desc = "\x00a9 Novell Inc.";
+			PixbufOrientation orient = PixbufOrientation.TopRight;
+
+			PixbufUtils.SaveJpeg (test, path, quality, new Exif.ExifData ());
+			FSpot.JpegFile jimg = new FSpot.JpegFile (path);
+			jimg.SetDescription (desc);
+			jimg.SetOrientation (orient);
+			jimg.SaveMetaData (path);
+			
+			return path;
+		}
+
+		[Test]
+		public void Load ()
+		{
+			string path = CreateFile ();
+
+			using (Stream stream = File.OpenRead (path)) {
+				JpegHeader jhead = new JpegHeader (stream);
+
+				Assert.AreEqual (((Marker)jhead.Markers [0]).Type, JpegMarker.Soi);
+				Assert.AreEqual (((Marker)jhead.Markers [1]).GetName (), "JFIF");
+				Assert.AreEqual (((Marker)jhead.Markers [1]).Type, JpegMarker.App0);
+				Assert.AreEqual (((Marker)jhead.Markers [2]).GetName (), "Exif");
+				Assert.AreEqual (((Marker)jhead.Markers [2]).Type, JpegMarker.App1);
+
+				// NOTE the currently we don't store the Eoi as the last marker
+				Assert.AreEqual (((Marker)jhead.Markers [jhead.Markers.Count -1]).Type, JpegMarker.Sos);
+
+				// NOTE this is kind of sill but it might help
+				Assert.IsTrue (Math.Abs (jhead.GuessQuality () - quality) <= 1);
+
+				Assert.IsNotNull (jhead.GetExifHeader ());
+			}
+
+			File.Delete (path);
+		}
+
+		[Test]
+		public void Save ()
+		{
+			string in_path = CreateFile ();
+			string out_path = ImageFile.TempPath ("output.jpg");
+			JpegHeader source;
+			JpegHeader dest;
+
+			using (Stream orig = File.OpenRead (in_path)) {
+				source = new JpegHeader (orig);
+				
+				using (Stream output = File.OpenWrite (out_path)) {
+					source.Save (output);
+				}
+
+				using (Stream result = File.OpenRead (out_path)) {
+					dest = new JpegHeader (result);
+					
+					Assert.AreEqual (source.Markers.Count, dest.Markers.Count);
+					Assert.AreEqual (source.GuessQuality (), dest.GuessQuality ());
+					Assert.AreEqual (orig.Length, result.Length);
+					for (int i = 0; i < source.Markers.Count; i++) {
+						Marker d = (Marker) dest.Markers [i];
+						Marker s = (Marker) source.Markers [i];
+
+						Assert.AreEqual (d.Type, s.Type);
+						Assert.AreEqual (d.GetName (), s.GetName ());
+
+						if (d.Data != null) {
+							Assert.AreEqual (d.Data.Length, s.Data.Length);
+						
+							for (int j = 0; j < d.Data.Length; j++) {
+								Assert.AreEqual (d.Data [j], s.Data [j]);
+							}
+						} else {
+							Assert.AreEqual (d.Data, s.Data);
+						}
+					}
+				}
+			}
+
+			File.Delete (in_path);
+			File.Delete (out_path);
+		}
+	}
+#endif
+
 #if false
 	public static int Main (string [] args)
 	{
