@@ -3,7 +3,7 @@ using Gtk;
 using GtkSharp;
 using Glade;
 using Gnome;
-using Mono.Posix;
+using Mono.Unix;
 using System;
 using System.Text;
 
@@ -87,7 +87,6 @@ public class MainWindow {
 	[Glade.Widget] MenuItem find_by_tag;
 	[Glade.Widget] MenuItem find_add_tag;
 	[Glade.Widget] MenuItem find_add_tag_with;
-	[Glade.Widget] MenuItem clear_tag_query;
 	
 	[Glade.Widget] MenuItem clear_date_range;
 
@@ -103,7 +102,7 @@ public class MainWindow {
 	// Other Widgets
 	[Glade.Widget] Scale zoom_scale;
 
-	[Glade.Widget] VPaned info_vpaned;
+	[Glade.Widget] VBox info_vbox;
 
 	[Glade.Widget] Gtk.Image near_image;
 	[Glade.Widget] Gtk.Image far_image;
@@ -135,7 +134,6 @@ public class MainWindow {
 	Widget rl_button;
 	Widget rr_button;
 	
-	string last_import_path;
 	ModeType view_mode;
 	bool write_metadata = false;
 
@@ -194,9 +192,9 @@ public class MainWindow {
 		get { return selection; }
 	}
 
-	public MenuItem ClearFindByTag {
-		get { return clear_tag_query; }
-	}
+    public MenuItem FindByTag {
+        get { return find_by_tag; }
+    }
 
 	//
 	// Constructor
@@ -208,24 +206,26 @@ public class MainWindow {
 		if (Toplevel == null)
 			Toplevel = this;
 
-		Glade.XML gui = Glade.XML.FromAssembly ("f-spot.glade", "main_window", "f-spot");
+		Glade.XML gui = new Glade.XML (null, "f-spot.glade", "main_window", null);
 		gui.Autoconnect (this);
 
 		LoadPreference (Preferences.MAIN_WINDOW_WIDTH);
 		LoadPreference (Preferences.MAIN_WINDOW_X);
 		LoadPreference (Preferences.MAIN_WINDOW_MAXIMIZED);
+		main_window.ShowAll ();
+
 		LoadPreference (Preferences.SIDEBAR_POSITION);
 		LoadPreference (Preferences.METADATA_EMBED_IN_IMAGE);
-
+		
 		slide_delay = new FSpot.Delay (new GLib.IdleHandler (SlideShow));
-
+		
 		toolbar = new Gtk.Toolbar ();
 		toolbar_vbox.PackStart (toolbar);
-
+		
 		rl_button = GtkUtil.MakeToolbarButton (toolbar, "f-spot-rotate-270", new System.EventHandler (HandleRotate270Command));
 		rr_button = GtkUtil.MakeToolbarButton (toolbar, "f-spot-rotate-90", new System.EventHandler (HandleRotate90Command));
 		toolbar.AppendSpace ();
-
+		
 		// FIXME putting these two toggle buttons in a radio group would prevent
 		// the two toggle sounds from being emitted every time you switch modes
 		browse_button = GtkUtil.MakeToolbarToggleButton (toolbar, "f-spot-browse", 
@@ -247,7 +247,6 @@ public class MainWindow {
 		tag_selection_scrolled.Add (tag_selection_widget);
 		
 		tag_selection_widget.Selection.Changed += HandleTagSelectionChanged;
-		tag_selection_widget.SelectionChanged += OnTagSelectionChanged;
 		tag_selection_widget.DragDataGet += HandleTagSelectionDragDataGet;
 		tag_selection_widget.DragDrop += HandleTagSelectionDragDrop;
 		tag_selection_widget.DragBegin += HandleTagSelectionDragBegin;
@@ -266,6 +265,7 @@ public class MainWindow {
 		
 		info_box = new InfoBox ();
 		info_box.VersionIdChanged += HandleInfoBoxVersionIdChange;
+        info_box.HeightRequest = 165;
 		left_vbox.PackStart (info_box, false, true, 0);
 		
 		try {
@@ -276,7 +276,7 @@ public class MainWindow {
 			query = new FSpot.PhotoQuery (db.Photos);
 		}
 
-        UpdateStatusLabel ();
+		UpdateStatusLabel ();
 		query.Changed += HandleQueryChanged;
 
 		db.Photos.ItemsChanged += HandleDbItemsChanged;
@@ -378,11 +378,14 @@ public class MainWindow {
 		this.selection.ItemsChanged += HandleSelectionItemsChanged;
 
 		UpdateMenus ();
+
 		main_window.ShowAll ();
 
 		tagbar.Hide ();
 		find_bar.Hide ();
 
+        UpdateFindByTagMenu ();
+
 		LoadPreference (Preferences.SHOW_TOOLBAR);
 		LoadPreference (Preferences.SHOW_SIDEBAR);
 		LoadPreference (Preferences.SHOW_TIMELINE);
@@ -436,7 +439,7 @@ public class MainWindow {
 			if (view_notebook.CurrentPage != 0)
 				view_notebook.CurrentPage = 0;
 				
-            ColorDialog.Close ();
+			ColorDialog.Close ();
 			JumpTo (photo_view.Item.Index);
 			zoom_scale.Value = icon_view.Zoom;
 			break;
@@ -493,6 +496,7 @@ public class MainWindow {
 	{
 		icon_view.QueueDraw ();
 		UpdateTagEntryFromSelection ();
+		
 	}
 
 	void HandleViewNotebookSwitchPage (object sender, SwitchPageArgs args)
@@ -507,8 +511,6 @@ public class MainWindow {
 		}
 	}
 
-	private int lastTopLeftCell = -1;
-
 	public int [] SelectedIds () {
 		int [] ids = new int [0];
 
@@ -657,6 +659,7 @@ public class MainWindow {
 
 		UpdateMenus ();
 		UpdateTagEntryFromSelection ();
+		UpdateStatusLabel();		
 	}
 
 	private void HandleSelectionItemsChanged (IBrowsableCollection collection, BrowsableArgs args)
@@ -746,7 +749,7 @@ public class MainWindow {
 
 	void HandleTagSelectionRowActivated (object sender, RowActivatedArgs args)
 	{
-        ShowQueryWidget ();
+		ShowQueryWidget ();
 		//query_widget.Require (new Tag [] {tag_selection_widget.TagByPath (args.Path)});
 		query_widget.Include (new Tag [] {tag_selection_widget.TagByPath (args.Path)});
 	}
@@ -772,8 +775,8 @@ public class MainWindow {
 	void RestoreDb (System.Exception e)
 	{
 		string backup = db.Repair ();
-		string short_msg = Mono.Posix.Catalog.GetString ("Error loading database.");
-		string long_msg = Mono.Posix.Catalog.GetString ("F-Spot encountered an error while loading the photo database. " + 
+		string short_msg = Catalog.GetString ("Error loading database.");
+		string long_msg = Catalog.GetString ("F-Spot encountered an error while loading the photo database. " + 
 								"The old database has be moved to {0} and a new database has been created.");
 
 		HigMessageDialog md = new HigMessageDialog (main_window, DialogFlags.DestroyWithParent, 
@@ -822,10 +825,10 @@ public class MainWindow {
 		case (uint) TargetType.TagList:
 			Byte [] data = Encoding.UTF8.GetBytes (list.ToString ());
 			Atom [] targets = args.Context.Targets;
-		
+			
 			args.SelectionData.Set (targets[0], 8, data, data.Length);
 			break;
-		} 
+		}
 	}
 
 	void HandleTagSelectionDragDrop (object sender, DragDropArgs args)
@@ -967,7 +970,6 @@ public class MainWindow {
 		if (cell_num == -1 /*|| cell_num == lastTopLeftCell*/)
 			return;
 
-		lastTopLeftCell = cell_num;
 		FSpot.IBrowsableItem photo = icon_view.Collection.Items [cell_num];
 #if false
 		group_selector.Adaptor.GlassSet -= HandleAdaptorGlassSet;
@@ -1084,6 +1086,7 @@ public class MainWindow {
 		if (args.Event.Key == Gdk.Key.Delete) {
 			HandleRemoveCommand (sender, (EventArgs) args);
 		}
+		UpdateStatusLabel();		
 	}
 
 	public void ImportUriList (UriList list, bool copy) 
@@ -1307,7 +1310,6 @@ public class MainWindow {
 		db.Sync = false;
 		ImportCommand command = new ImportCommand (main_window);
 		if (command.ImportFromFile (db.Photos, null) > 0) {
-			this.last_import_path = command.ImportPath;
 			UpdateQuery ();
 		}
 		db.Sync = true;		
@@ -1329,8 +1331,8 @@ public class MainWindow {
 			if (num_cameras < 1) {
 				HigMessageDialog md = new HigMessageDialog (main_window, DialogFlags.DestroyWithParent, 
 					MessageType.Warning, ButtonsType.Ok, 
-					Mono.Posix.Catalog.GetString ("No cameras detected."),
-					Mono.Posix.Catalog.GetString ("F-Spot was unable to find any cameras attached to this system." + 
+					Catalog.GetString ("No cameras detected."),
+					Catalog.GetString ("F-Spot was unable to find any cameras attached to this system." + 
 								      "  Double check that the camera is connected and has power")); 
 
 				md.Run ();
@@ -1370,8 +1372,8 @@ public class MainWindow {
 			System.Console.WriteLine (ge.ToString ());
 			HigMessageDialog md = new HigMessageDialog (main_window, DialogFlags.DestroyWithParent, 
 				MessageType.Error, ButtonsType.Ok, 
-				Mono.Posix.Catalog.GetString ("Error connecting to camera"),
-				String.Format (Mono.Posix.Catalog.GetString ("Received error \"{0}\" while connecting to camera"), 
+				Catalog.GetString ("Error connecting to camera"),
+				String.Format (Catalog.GetString ("Received error \"{0}\" while connecting to camera"), 
 				ge.Message));
 
 			md.Run ();
@@ -1460,7 +1462,7 @@ public class MainWindow {
 
 	void HandleExportToFlickr (object sender, EventArgs args)
 	{
-		new FSpot.FlickrExport (new FSpot.PhotoArray (SelectedPhotos ()));
+		new FSpot.FlickrExport (new FSpot.PhotoArray (SelectedPhotos ()), true);
 	}
 	
 	void HandleExportToFotki (object sender, EventArgs args)
@@ -1473,11 +1475,31 @@ public class MainWindow {
 		new FSpot.CDExport (new FSpot.PhotoArray (SelectedPhotos ()));
 	}
 
+#if false
+	void TestDisplay ()
+	{
+		Gtk.Window win = new Gtk.Window ("hello");
+		VBox box = new VBox ();
+		box.PackStart (new FSpot.Widgets.ImageDisplay (new BrowsablePointer (new FSpot.PhotoArray (SelectedPhotos ()), 0)));
+		win.Add (box);
+		win.ShowAll ();
+	}
+#endif
+
 	void HandleSendMailCommand (object sender, EventArgs args)
 	{
+		//TestDisplay ();
 		new FSpot.SendEmail (new FSpot.PhotoArray (SelectedPhotos ()));
 	}
 
+	public static void HandleHelp (object sender, EventArgs args)
+	{
+		Gnome.Vfs.Url.Show("ghelp:" + 
+				FSpot.Global.HelpDirectory +
+				System.IO.Path.DirectorySeparatorChar +
+				"index.xml");
+	}
+
 	public static void HandleAbout (object sender, EventArgs args)
 	{
 		string [] authors = new string [] {
@@ -1487,6 +1509,7 @@ public class MainWindow {
 			"Alex Graveley",
 			"Todd Berman",
 			"Ben Monnahan",
+			"Stephane Delcroix",
 			"Vladimir Vukicevic",
 			"Aaron Bockover",
 			"Bengt Thuree",
@@ -1517,15 +1540,16 @@ public class MainWindow {
                 // Translators should localize the following string
                 // * which will give them credit in the About box.
                 // * E.g. "Martin Willemoes Hansen"
-                string translators = Mono.Posix.Catalog.GetString ("translator-credits");
+                string translators = Catalog.GetString ("translator-credits");
                 if(System.String.Compare(translators,"translator-credits") == 0) {
                     translators = null;
                 }
 
                 new About ("F-Spot", 
 			   FSpot.Defines.VERSION, 
-			   Mono.Posix.Catalog.GetString ("Copyright \x00a9 2003-2006 Novell Inc."),
-                           null, authors, new string [0], translators, null).Show();
+			   Catalog.GetString ("Copyright \x00a9 2003-2006 Novell Inc."),
+                           null, authors, new string [0], translators, 
+			   PixbufUtils.LoadFromAssembly("f-spot-logo-tango.svg")).Show();
 	}
 
 	public void HandleArrangeByTime (object sender, EventArgs args)
@@ -1617,7 +1641,7 @@ public class MainWindow {
 		}
 
 		Preferences.Set (Preferences.SHOW_TOOLBAR,		toolbar.Visible);
-		Preferences.Set (Preferences.SHOW_SIDEBAR,		info_vpaned.Visible);
+		Preferences.Set (Preferences.SHOW_SIDEBAR,		info_vbox.Visible);
 		Preferences.Set (Preferences.SHOW_TIMELINE,		group_selector.Visible);
 		Preferences.Set (Preferences.SHOW_TAGS,			icon_view.DisplayTags);
 		Preferences.Set (Preferences.SHOW_DATES,		icon_view.DisplayDates);
@@ -1756,7 +1780,7 @@ public class MainWindow {
 			return;
 		
 		// Translators, The singular case will never happen here.
-		string header = Mono.Posix.Catalog.GetPluralString ("Merge the selected tag",
+		string header = Catalog.GetPluralString ("Merge the selected tag",
 								    "Merge the {0} selected tags?", tags.Length);
 		header = String.Format (header, tags.Length);
 
@@ -1783,9 +1807,9 @@ public class MainWindow {
 			System.Console.WriteLine ("tag: {0}", tag.Name);
 		}
 
-		string msg = Mono.Posix.Catalog.GetString("This operation will merge the selected tags and any sub-tags into a single tag.");
+		string msg = Catalog.GetString("This operation will merge the selected tags and any sub-tags into a single tag.");
 
-		string ok_caption = Mono.Posix.Catalog.GetString ("_Merge Tags");
+		string ok_caption = Catalog.GetString ("_Merge Tags");
 		
 		if (ResponseType.Ok != HigMessageDialog.RunHigConfirmation(main_window, 
 									   DialogFlags.DestroyWithParent, 
@@ -1834,7 +1858,7 @@ public class MainWindow {
 
 	void HandleSharpen (object sender, EventArgs args)
 	{
-		Gtk.Dialog dialog = new Gtk.Dialog (Mono.Posix.Catalog.GetString ("Unsharp Mask"), main_window, Gtk.DialogFlags.Modal);
+		Gtk.Dialog dialog = new Gtk.Dialog (Catalog.GetString ("Unsharp Mask"), main_window, Gtk.DialogFlags.Modal);
 
 		dialog.VBox.Spacing = 6;
 		dialog.VBox.BorderWidth = 12;
@@ -1843,9 +1867,9 @@ public class MainWindow {
 		table.ColumnSpacing = 6;
 		table.RowSpacing = 6;
 		
-		table.Attach (new Gtk.Label (Mono.Posix.Catalog.GetString ("Amount:")), 0, 1, 0, 1);
-		table.Attach (new Gtk.Label (Mono.Posix.Catalog.GetString ("Radius:")), 0, 1, 1, 2);
-		table.Attach (new Gtk.Label (Mono.Posix.Catalog.GetString ("Threshold:")), 0, 1, 2, 3);
+		table.Attach (new Gtk.Label (Catalog.GetString ("Amount:")), 0, 1, 0, 1);
+		table.Attach (new Gtk.Label (Catalog.GetString ("Radius:")), 0, 1, 1, 2);
+		table.Attach (new Gtk.Label (Catalog.GetString ("Threshold:")), 0, 1, 2, 3);
 
 		Gtk.SpinButton amount_spin = new Gtk.SpinButton (0.5, 100.0, .01);
 		Gtk.SpinButton radius_spin = new Gtk.SpinButton (5.0, 50.0, .01);
@@ -1876,8 +1900,8 @@ public class MainWindow {
 					photo.SaveVersion (final, create_version);
 					query.Commit (id);
 				} catch (System.Exception e) {
-					string msg = Mono.Posix.Catalog.GetString ("Error saving sharpened photo");
-					string desc = String.Format (Mono.Posix.Catalog.GetString ("Received exception \"{0}\". Unable to save photo {1}"),
+					string msg = Catalog.GetString ("Error saving sharpened photo");
+					string desc = String.Format (Catalog.GetString ("Received exception \"{0}\". Unable to save photo {1}"),
 								     e.Message, photo.Name.Replace ("_", "__"));
 					
 					HigMessageDialog md = new HigMessageDialog (main_window, DialogFlags.DestroyWithParent, 
@@ -1925,10 +1949,10 @@ public class MainWindow {
 
 	void HandleDisplayInfoSidebar (object sender, EventArgs args)
 	{
-		if (info_vpaned.Visible)
-			info_vpaned.Hide ();
+		if (info_vbox.Visible)
+			info_vbox.Hide ();
 		else
-			info_vpaned.Show ();
+			info_vbox.Show ();
 	}
 
 	void HandleViewSlideShow (object sender, EventArgs args)
@@ -2000,13 +2024,13 @@ public class MainWindow {
 		if (fsview == null) {
 			fsview = new FSpot.FullScreenView (query);
 			fsview.Destroyed += HandleFullScreenViewDestroy;
-            fsview.View.Item.Index = active;
-            ColorDialog.SwitchViews (fsview.View);
+			fsview.View.Item.Index = active;
+			ColorDialog.SwitchViews (fsview.View);
 		} else {
-            // FIXME this needs to be another mode like PhotoView and IconView mode.
-            fsview.View.Item.Index = active;
-        }
-
+			// FIXME this needs to be another mode like PhotoView and IconView mode.
+			fsview.View.Item.Index = active;
+		}
+		
 		fsview.Show ();
 	}
 
@@ -2014,10 +2038,10 @@ public class MainWindow {
 	{
 		JumpTo (fsview.View.Item.Index);
 		fsview = null;
-
-        if (ViewMode == ModeType.PhotoView) {
-            ColorDialog.SwitchViews (photo_view.View);
-        }
+		
+		if (ViewMode == ModeType.PhotoView) {
+			ColorDialog.SwitchViews (photo_view.View);
+		}
 	}
 	
 	void HandleZoomScaleValueChanged (object sender, System.EventArgs args)
@@ -2051,7 +2075,24 @@ public class MainWindow {
 
 	private void UpdateStatusLabel ()
 	{
-		status_label.Text = String.Format (Catalog.GetPluralString ("{0} Photo", "{0} Photos", query.Count), query.Count);
+		StringBuilder label_str = new StringBuilder();
+		
+		switch (view_mode) {
+		case ModeType.PhotoView:
+			break;
+		case ModeType.IconView:		
+			label_str.Append (String.Format (Catalog.GetPluralString ("{0} Photo", "{0} Photos", query.Count), query.Count));
+
+			if (PhotoStore.TotalPhotos != query.Count)
+				label_str.Append (String.Format (Catalog.GetString (" out of {0}"), PhotoStore.TotalPhotos));
+
+			if ((selection != null) && (selection.Count > 0))
+				label_str.Append (String.Format (Catalog.GetPluralString (" ({0} selected)", " ({0} selected)", selection.Count), selection.Count));
+			break;
+		}
+		
+		status_label.Text = label_str.ToString();
+		status_label.UseMarkup = true;
 	}
 	
 	void HandleZoomChanged (object sender, System.EventArgs args)
@@ -2130,17 +2171,17 @@ public class MainWindow {
 
 	public void DeleteException (Exception e, string fname)
 	{
-		string ok_caption = Mono.Posix.Catalog.GetString ("_Ok");
-		string error = Mono.Posix.Catalog.GetString ("Error Deleting Picture");
+		string ok_caption = Catalog.GetString ("_Ok");
+		string error = Catalog.GetString ("Error Deleting Picture");
 		string msg;
 
 		if (e is UnauthorizedAccessException)
 			msg = String.Format (
-				Mono.Posix.Catalog.GetString ("No permission to delete the file:\n{0}"), 
+				Catalog.GetString ("No permission to delete the file:\n{0}"), 
 				fname).Replace ("_", "__");
 		else
 			msg = String.Format (
-				Mono.Posix.Catalog.GetString ("An error of type {0} occurred while deleting the file:\n{1}"),
+				Catalog.GetString ("An error of type {0} occurred while deleting the file:\n{1}"),
 				e.GetType (), fname.Replace ("_", "__"));
 		
 		HigMessageDialog.RunHigConfirmation (
@@ -2166,14 +2207,14 @@ public class MainWindow {
 	public void HandleDeleteCommand (object sender, EventArgs args)
 	{
    		Photo[] photos = SelectedPhotos();
-   		string header = Mono.Posix.Catalog.GetPluralString ("Delete the selected photo permanently?", 
+   		string header = Catalog.GetPluralString ("Delete the selected photo permanently?", 
 								    "Delete the {0} selected photos permanently?", 
 								    photos.Length);
 		header = String.Format (header, photos.Length);
-		string msg = Mono.Posix.Catalog.GetPluralString ("This deletes all versions of the selected photo from your drive.", 
+		string msg = Catalog.GetPluralString ("This deletes all versions of the selected photo from your drive.", 
 								 "This deletes all versions of the selected photos from your drive.", 
 								 photos.Length);
-		string ok_caption = Mono.Posix.Catalog.GetPluralString ("_Delete photo", "_Delete photos", photos.Length);
+		string ok_caption = Catalog.GetPluralString ("_Delete photo", "_Delete photos", photos.Length);
 		
 
 
@@ -2201,13 +2242,13 @@ public class MainWindow {
 	public void HandleRemoveCommand (object sender, EventArgs args)
 	{
    		Photo[] photos = SelectedPhotos();
-   		string header = Mono.Posix.Catalog.GetPluralString ("Remove the selected photo from F-Spot?",
+   		string header = Catalog.GetPluralString ("Remove the selected photo from F-Spot?",
 								    "Remove the {0} selected photos from F-Spot?", 
 								    photos.Length);
 
 		header = String.Format (header, photos.Length);
-		string msg = Mono.Posix.Catalog.GetString("If you remove photos from the F-Spot catalog all tag information will be lost. The photos remain on your computer and can be imported into F-Spot again.");
-		string ok_caption = Mono.Posix.Catalog.GetString("_Remove from Catalog");
+		string msg = Catalog.GetString("If you remove photos from the F-Spot catalog all tag information will be lost. The photos remain on your computer and can be imported into F-Spot again.");
+		string ok_caption = Catalog.GetString("_Remove from Catalog");
 		if (ResponseType.Ok == HigMessageDialog.RunHigConfirmation(GetToplevel (sender), DialogFlags.DestroyWithParent, 
 									   MessageType.Warning, header, msg, ok_caption)) {                              
 			db.Photos.Remove (photos);
@@ -2218,11 +2259,13 @@ public class MainWindow {
 	void HandleSelectAllCommand (object sender, EventArgs args)
 	{
 		icon_view.SelectAllCells ();
+		UpdateStatusLabel();
 	}
 
 	void HandleSelectNoneCommand (object sender, EventArgs args)
 	{
 		icon_view.Selection.Clear ();
+		UpdateStatusLabel();
 	}
 
 	// This ConnectBefore is needed because otherwise the editability of the name
@@ -2262,13 +2305,13 @@ public class MainWindow {
 
 		string header;
 		if (tags.Length == 1)
-			header = String.Format (Mono.Posix.Catalog.GetString ("Delete tag \"{0}\"?"), tags [0].Name.Replace ("_", "__"));
+			header = String.Format (Catalog.GetString ("Delete tag \"{0}\"?"), tags [0].Name.Replace ("_", "__"));
 		else
-			header = String.Format (Mono.Posix.Catalog.GetString ("Delete the {0} selected tags?"), tags.Length);
+			header = String.Format (Catalog.GetString ("Delete the {0} selected tags?"), tags.Length);
 		
 		header = String.Format (header, tags.Length);
-		string msg = Mono.Posix.Catalog.GetString("If you delete a tag, all associations with photos are lost.");
-		string ok_caption = Mono.Posix.Catalog.GetPluralString ("_Delete tag", "_Delete tags", tags.Length);
+		string msg = Catalog.GetString("If you delete a tag, all associations with photos are lost.");
+		string ok_caption = Catalog.GetPluralString ("_Delete tag", "_Delete tags", tags.Length);
 		
 		if (ResponseType.Ok == HigMessageDialog.RunHigConfirmation(main_window, 
 									   DialogFlags.DestroyWithParent, 
@@ -2282,8 +2325,8 @@ public class MainWindow {
 				System.Console.WriteLine ("this is something or another");
 
 				// A Category is not empty. Can not delete it.
-				string error_msg = Mono.Posix.Catalog.GetString ("Tag is not empty");
-				string error_desc = String.Format (Mono.Posix.Catalog.GetString ("Can not delete tags that have tags within them.  " + 
+				string error_msg = Catalog.GetString ("Tag is not empty");
+				string error_desc = String.Format (Catalog.GetString ("Can not delete tags that have tags within them.  " + 
 												 "Please delete tags under \"{0}\" first"),
 								   e.Tag.Name.Replace ("_", "__"));
 				
@@ -2356,17 +2399,11 @@ public class MainWindow {
 	void HandleSetAsBackgroundCommand (object sender, EventArgs args)
 	{
 		Photo current = CurrentPhoto;
-		GConf.Client client = new GConf.Client ();
-		
+
 		if (current == null)
 			return;
 
-		client.Set ("/desktop/gnome/background/color_shading_type", "solid");
-		client.Set ("/desktop/gnome/background/primary_color", "#000000");
-		client.Set ("/desktop/gnome/background/picture_options", "scaled");
-		client.Set ("/desktop/gnome/background/picture_opacity", 100);
-		client.Set ("/desktop/gnome/background/picture_filename", current.DefaultVersionUri.LocalPath);
-		client.Set ("/desktop/gnome/background/draw_background", true);
+		Preferences.SetAsBackground (current.DefaultVersionUri.LocalPath);
 	}
 
 	void HandleSetDateRange (object sender, EventArgs args) {
@@ -2388,16 +2425,7 @@ public class MainWindow {
 		if (query.Untagged == find_untagged.Active)
 			return;
 
-		if (query.Untagged)
-			query.Untagged = false;
-		else {
-			// Having tags selected wouldn't make sense
-			tag_selection_widget.SelectionChanged -= OnTagSelectionChanged;
-			tag_selection_widget.TagSelection = new Tag [] {};
-			tag_selection_widget.SelectionChanged += OnTagSelectionChanged;
-
-			query.Untagged = true;
-		}
+		query.Untagged = !query.Untagged;
 	}
 	
 	void OnPreferencesChanged (object sender, GConf.NotifyEventArgs args)
@@ -2430,10 +2458,9 @@ public class MainWindow {
 		
 		case Preferences.MAIN_WINDOW_WIDTH:
 		case Preferences.MAIN_WINDOW_HEIGHT:
-			main_window.SetDefaultSize((int) Preferences.Get(Preferences.MAIN_WINDOW_WIDTH),
+			main_window.Resize((int) Preferences.Get(Preferences.MAIN_WINDOW_WIDTH),
 					(int) Preferences.Get(Preferences.MAIN_WINDOW_HEIGHT));
 
-			main_window.ReshowWithInitialSize();
 			break;
 		
 		case Preferences.SHOW_TOOLBAR:
@@ -2482,7 +2509,7 @@ public class MainWindow {
 					
 					if (photo != null)
 						JumpTo (query.IndexOf (photo));
-				} catch (Exception e) {}
+				} catch (Exception) {}
 			}
 			break;
 		case Preferences.SIDEBAR_POSITION:
@@ -2527,16 +2554,10 @@ public class MainWindow {
 	{
 		main_window.GdkWindow.Cursor = new Gdk.Cursor (Gdk.CursorType.Watch);
 		main_window.GdkWindow.Display.Sync ();
-		query.Tags = tag_selection_widget.TagSelection;
+		query.RequestReload ();
 		main_window.GdkWindow.Cursor = null;
 	}
 
-	void OnTagSelectionChanged (object obj)
-	{
-		UpdateQuery ();
-		SetViewMode (ModeType.IconView);
-	}
-	
 	void HandleTagSelectionChanged (object obj, EventArgs args)
 	{
 		UpdateMenus ();
@@ -2570,7 +2591,16 @@ public class MainWindow {
 
     void HandleFindByTag (object sender, EventArgs args)
     {
-        ShowQueryWidget ();
+        UpdateFindByTagMenu ();
+    }
+
+    public void UpdateFindByTagMenu ()
+    {
+        if (query_widget.Visible) {
+            query_widget.Close ();
+        } else {
+            ShowQueryWidget ();
+        }
     }
 
     void HandleFindAddTagWith (object sender, EventArgs args)
@@ -2622,11 +2652,6 @@ public class MainWindow {
 		query_widget.Require (new Tag [] {t});
     }
 
-	void HandleClearTagSearch (object sender, EventArgs args)
-	{
-		query_widget.ClearTags ();
-	}
-	
 	//
 	// Handle Main Menu 
 
@@ -3091,37 +3116,36 @@ public class MainWindow {
 		return mimes.ToArray (typeof (string)) as string [];
 	}
 
-    private void ShowQueryWidget () {
-        if (find_bar.Visible) {
-            find_bar.Entry.Text = "";
-            find_bar.Hide ();
-        }
-
-        query_widget.Show ();
-        return;
-    }
-
+	private void ShowQueryWidget () {
+		if (find_bar.Visible) {
+			find_bar.Entry.Text = "";
+			find_bar.Hide ();
+		}
+		
+		query_widget.ShowBar ();
+		return;
+	}
+	
 	public void HandleKeyPressEvent (object sender, Gtk.KeyPressEventArgs args)
-    {
+	{
 		bool ctrl = ModifierType.ControlMask == (args.Event.State & ModifierType.ControlMask);
 
-        if ((ctrl && args.Event.Key == Gdk.Key.F) || args.Event.Key == Gdk.Key.slash) {
-            if (!find_bar.Visible) {
-                if (query_widget.Visible) {
-                    query_widget.ClearTags ();
-                    query_widget.Hide ();
-                }
-
-                find_bar.Show ();
-                find_bar.Entry.GrabFocus ();
-                args.RetVal = true;
-                return;
-            }
-        }
-
-        args.RetVal = false;
-    }
-
+		if ((ctrl && args.Event.Key == Gdk.Key.F) || args.Event.Key == Gdk.Key.slash) {
+			if (!find_bar.Visible) {
+				if (query_widget.Visible) {
+					query_widget.Close ();
+				}
+				
+				find_bar.Show ();
+				find_bar.Entry.GrabFocus ();
+				args.RetVal = true;
+				return;
+			}
+		}
+		
+		args.RetVal = false;
+	}
+	
 	public static void SetTip (Widget widget, string tip)
 	{
 		toolTips.SetTip (widget, tip, null);
