@@ -1,13 +1,17 @@
 using Gnome;
 using Gdk;
 using Gtk;
+
 using Mono.Data.SqliteClient;
+using Mono.Unix;
+
 using System.Collections;
 using System.IO;
 using System.Text;
 using System;
 using FSpot;
 
+
 public class PhotoVersion : FSpot.IBrowsableItem {
 	Photo photo;
 	uint version_id;
@@ -156,7 +160,7 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 
 	private string Path {
 		get {
-			return directory_path + "/" + name;
+			return System.IO.Path.Combine (directory_path, name);
 		}
 	}
 
@@ -288,15 +292,14 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 			return GetPathForVersionName (GetVersionName (version_id));
 	}
 
-	public string DefaultVersionPath {
-		get {
-			return GetVersionPath (DefaultVersionId);
-		}
+	public System.Uri VersionUri (uint version_id)
+	{
+		return UriList.PathToFileUri (GetVersionPath (version_id));
 	}
-
+	
 	public System.Uri DefaultVersionUri {
 		get {
-			return UriList.PathToFileUri (DefaultVersionPath);
+			return VersionUri (DefaultVersionId);
 		}
 	}
 
@@ -313,6 +316,14 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 		string path = GetVersionPath (version_id);
 		if (File.Exists (path))
 			File.Delete (path);
+
+		try {
+			string thumb_path = ThumbnailGenerator.ThumbnailPath (path);
+			File.Delete (thumb_path);
+		} catch (System.Exception) {
+			//ignore an error here we don't really care.
+		}
+
 		PhotoStore.DeleteThumbnail (path);
 
 		version_names.Remove (version_id);
@@ -357,7 +368,7 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 		int num = 1;
 
 		while (true) {
-			string name = Mono.Posix.Catalog.GetPluralString ("Modified", 
+			string name = Catalog.GetPluralString ("Modified", 
 								 "Modified ({0})", 
 								 num);
 			name = String.Format (name, num);
@@ -376,7 +387,7 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 		string final_name;
 		while (true) {
 			final_name = String.Format (
-					Mono.Posix.Catalog.GetPluralString ("Modified in {1}", "Modified in {1} ({0})", num),
+					Catalog.GetPluralString ("Modified in {1}", "Modified in {1} ({0})", num),
 					num, name);
 
 			if (num > 1)
@@ -491,9 +502,9 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 
 	public void WriteMetadataToImage ()
 	{
-		string path = this.DefaultVersionPath;
+		string path = this.DefaultVersionUri.LocalPath;
 
-		FSpot.ImageFile img = FSpot.ImageFile.Create (path);
+		FSpot.ImageFile img = FSpot.ImageFile.Create (DefaultVersionUri);
 		if (img is FSpot.JpegFile) {
 			FSpot.JpegFile jimg = img as FSpot.JpegFile;
 			
@@ -517,7 +528,7 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 	public uint SaveVersion (Gdk.Pixbuf buffer, bool create_version)
 	{
 		uint version = DefaultVersionId;
-		ImageFile img = ImageFile.Create (DefaultVersionUri.LocalPath);
+		ImageFile img = ImageFile.Create (DefaultVersionUri);
 
 		// Always create a version if the source is not a jpeg for now.
 		create_version = create_version || !(img is FSpot.JpegFile);
@@ -560,7 +571,7 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 
 		// Note that the original version is never stored in the photo_versions table in the
 		// database.
-		AddVersionUnsafely (OriginalVersionId, Mono.Posix.Catalog.GetString ("Original"));
+		AddVersionUnsafely (OriginalVersionId, Catalog.GetString ("Original"));
 	}
 
 	public Photo (uint id, long unix_time, string path)
@@ -575,7 +586,13 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 
 public class PhotoStore : DbStore {
 	TagStore tag_store;
-	
+
+	static int total_photos = 0;
+	public static int TotalPhotos {
+		get { return total_photos; }
+		set { total_photos = value; }
+	}
+
 	public static ThumbnailFactory ThumbnailFactory = new ThumbnailFactory (ThumbnailSize.Large);
 
 	// FIXME this is a hack.  Since we don't have Gnome.ThumbnailFactory.SaveThumbnail() in
@@ -594,11 +611,16 @@ public class PhotoStore : DbStore {
 	// Generates the thumbnail, returns the Pixbuf, and also stores it as a side effect
 	//
 
-	public static Pixbuf GenerateThumbnail (string path)
+	public static Pixbuf GenerateThumbnail (Uri uri)
+	{
+		FSpot.ImageFile img = FSpot.ImageFile.Create (uri);
+		
+		return GenerateThumbnail (uri, img);
+	}
+
+	public static Pixbuf GenerateThumbnail (Uri uri, ImageFile img)
 	{
-		string uri = UriList.PathToFileUri (path).ToString ();
 		Pixbuf thumbnail = null;
-		FSpot.ImageFile img = FSpot.ImageFile.Create (path);
 
 		if (img is FSpot.IThumbnailContainer) {
 			try {
@@ -610,10 +632,10 @@ public class PhotoStore : DbStore {
 
 		// Save embedded thumbnails in a silightly invalid way so that we know to regnerate them later.
 		if (thumbnail != null) 
-			PixbufUtils.SaveAtomic (thumbnail, Thumbnail.PathForUri (uri, ThumbnailSize.Large), 
+			PixbufUtils.SaveAtomic (thumbnail, FSpot.ThumbnailGenerator.ThumbnailPath (uri), 
 						"png", new string [] { null} , new string [] { null});
 		else 
-			thumbnail = FSpot.ThumbnailGenerator.Create (path);
+			thumbnail = FSpot.ThumbnailGenerator.Create (uri);
 		
 		return thumbnail;
 	}
@@ -644,10 +666,23 @@ public class PhotoStore : DbStore {
 		this.tag_store = tag_store;
 		EnsureThumbnailDirectory ();
 
-		if (! is_new)
-			return;
+		SqliteCommand command;
+
+		if (! is_new) {
+			command = new SqliteCommand ();
+			command.Connection = Connection;
+			command.CommandText = String.Format ("SELECT count(*) from photos");
+			SqliteDataReader reader = command.ExecuteReader ();
+	
+			while (reader.Read ()) {
+				TotalPhotos = Convert.ToInt32 (reader [0]);
+			}
+			command.Dispose ();
 		
-		SqliteCommand command = new SqliteCommand ();
+			return;
+		}
+		
+		command = new SqliteCommand ();
 		command.Connection = Connection;
 
 		command.CommandText =
@@ -691,6 +726,8 @@ public class PhotoStore : DbStore {
 
 		command.ExecuteNonQuery ();
 		command.Dispose ();
+		
+		TotalPhotos = 0;
 	}
 
 
@@ -703,7 +740,7 @@ public class PhotoStore : DbStore {
 	{
 		FSpot.ImageFile img = FSpot.ImageFile.Create (origPath);
 		long unix_time = DbUtils.UnixTimeFromDateTime (img.Date);
-		string description = img.Description != null ? img.Description : "";
+		string description = img.Description != null  ? img.Description.Split ('\0') [0] : "";
 		SqliteCommand command = new SqliteCommand ();
 		command.Connection = Connection;
 
@@ -724,9 +761,11 @@ public class PhotoStore : DbStore {
 		AddToCache (photo);
 		photo.Loaded = true;
 
-		thumbnail = GenerateThumbnail (newPath);		
+		thumbnail = GenerateThumbnail (UriList.PathToFileUri (newPath), img);		
 		EmitAdded (photo);
 
+		TotalPhotos++;
+		
 		return photo;
 	}
 
@@ -948,8 +987,6 @@ public class PhotoStore : DbStore {
 		string directory_path = System.IO.Path.GetDirectoryName (path);
 		string filename = System.IO.Path.GetFileName (path);
 
-		directory_path = directory_path.Trim();
-		filename = filename.Trim();
 		command.CommandText = String.Format ("SELECT id,                                   " +
 				                     "       time,                                 " +
 						     "       description,                          " +
@@ -1013,6 +1050,7 @@ public class PhotoStore : DbStore {
 			query_builder.Append (String.Format ("id = {0}", items[i].Id));
 			tv_query_builder.Append (String.Format ("photo_id = {0}", items[i].Id));
 			RemoveFromCache (items[i]);
+			TotalPhotos--;			
 		}
 
 		SqliteCommand command = new SqliteCommand ();
@@ -1149,11 +1187,11 @@ public class PhotoStore : DbStore {
 	// Queries.
 	public Photo [] Query (Tag [] tags, DateTime start, DateTime end)
 	{
-		return Query (tags, new DateRange (start, end));
+		return Query (tags, null, new DateRange (start, end));
 	}
 	
 	public Photo [] Query (Tag [] tags) {
-		return Query (tags, null);
+		return Query (tags, null, null);
 	}
 
 	public Photo [] Query (string query)
@@ -1227,7 +1265,7 @@ public class PhotoStore : DbStore {
 					"(SELECT DISTINCT photo_id FROM photo_tags) ");
 		
 		if (range != null) {
-			query_builder.Append (String.Format ("AND photos.time >= {0} AND photos.time < {1} ",
+			query_builder.Append (String.Format ("AND photos.time >= {0} AND photos.time <= {1} ",
 							     DbUtils.UnixTimeFromDateTime (range.Start), 
 							     DbUtils.UnixTimeFromDateTime (range.End)));
 		}
@@ -1237,18 +1275,11 @@ public class PhotoStore : DbStore {
 		return Query (query_builder.ToString ());
 	}
 
-	public Photo [] Query (Tag [] tags, DateRange range)
+	public Photo [] Query (Tag [] tags, string extra_condition, DateRange range)
 	{
 		string query;
 
-		bool hide = true;
-		if (tags != null) {
-			foreach (Tag t in tags) {
-				if (tag_store.Hidden == null || t.Id == tag_store.Hidden.Id) 
-					hide = false;
-			}
-		} else
-			hide = tag_store.Hidden != null;
+		bool hide = (extra_condition == null);
 
 		// The SQL query that we want to construct is:
 		//
@@ -1260,9 +1291,10 @@ public class PhotoStore : DbStore {
 		//        photos.default_version_id
 		//                  FROM photos, photo_tags
 		//                  WHERE photos.id = photo_tags.photo_id
-		// 		          AND (photo_tags.tag_id = tag1
-		//			       OR photo_tags.tag_id = tag2
-		//                             OR photo_tags.tag_id = tag3 ...)
+		// 		                AND (photo_tags.tag_id = cat1tag1
+		//			            OR photo_tags.tag_id = cat1tag2 ) 
+		// 		                AND (photo_tags.tag_id = cat2tag1
+		//			            OR photo_tags.tag_id = cat2tag2 )
 		//                  GROUP BY photos.id
 		
 		StringBuilder query_builder = new StringBuilder ();
@@ -1275,12 +1307,12 @@ public class PhotoStore : DbStore {
 				      "     FROM photos                      ");
 		
 		if (range != null) {
-			query_builder.Append (String.Format ("WHERE photos.time >= {0} AND photos.time < {1} ",
+			query_builder.Append (String.Format ("WHERE photos.time >= {0} AND photos.time <= {1} ",
 							     DbUtils.UnixTimeFromDateTime (range.Start), 
 							     DbUtils.UnixTimeFromDateTime (range.End)));
 		}
 		
-		if (hide) {
+		if (hide && tag_store.Hidden != null) {
 			query_builder.Append (String.Format ("{0} photos.id NOT IN (SELECT photo_id FROM photo_tags WHERE tag_id = {1})", 
 							     range != null ? " AND " : " WHERE ", tag_store.Hidden.Id));
 		}
@@ -1307,6 +1339,16 @@ public class PhotoStore : DbStore {
 			if (!first)
 				query_builder.Append (")) ");
 		}
+
+		if (extra_condition != null) {
+			query_builder.Append (
+				String.Format (
+					"{0} {1} ",
+					(hide || range != null || (tags != null && tags.Length > 0)) ? " AND " : " WHERE ",
+					extra_condition
+				)
+			);
+		}
 		
 		query_builder.Append ("ORDER BY photos.time");
 		query = query_builder.ToString ();
