@@ -30,7 +30,6 @@ namespace FSpot {
 		private string password;
 		private string token;
 		private string unlock_captcha;
-		private bool connected;
 		private GoogleConnection connection;
 		private PicasaWeb picasa;
 
@@ -69,7 +68,6 @@ namespace FSpot {
 		private void MarkChanged()
 		{
 			connection = null;
-			connected = false;
 		}
 
 		public bool Connected {
@@ -406,7 +404,7 @@ namespace FSpot {
 	public class GoogleExport : GladeDialog {
 		public GoogleExport (IBrowsableCollection selection) : base ("google_export_dialog")
 		{
-			this.photos = (Photo []) selection.Items;
+			this.items = selection.Items;
 			album_button.Sensitive = false;
 			IconView view = new IconView (selection);
 			view.DisplayDates = false;
@@ -427,7 +425,6 @@ namespace FSpot {
 			if (edit_button != null)
 				edit_button.Clicked += HandleEditGallery;
 			
-			rh = new Gtk.ResponseHandler (HandleResponse);
 			Dialog.Response += HandleResponse;
 			connect = true;
 			HandleSizeActive (null, null);
@@ -442,8 +439,6 @@ namespace FSpot {
 //			LoadPreference (Preferences.EXPORT_PICASAWEB_META);
 		}
 		
-		Gtk.ResponseHandler rh;
-		
 		private bool scale;
 		private int size;
 		private bool browser;
@@ -454,7 +449,7 @@ namespace FSpot {
 		private long approx_size = 0;
 		private long sent_bytes = 0;
 
-		Photo [] photos;
+		IBrowsableItem [] items;
 		int photo_index;
 		FSpot.ThreadProgressDialog progress_dialog;
 		
@@ -464,10 +459,6 @@ namespace FSpot {
 
 		private string xml_path;
 
-		// Dialogs
-		private GoogleAccountDialog gallery_add;
-		private GoogleAddAlbum album_add;
-
 		// Widgets
 		[Glade.Widget] Gtk.OptionMenu gallery_optionmenu;
 		[Glade.Widget] Gtk.OptionMenu album_optionmenu;
@@ -521,9 +512,9 @@ namespace FSpot {
 				Dialog.Destroy ();
 
 				command_thread = new System.Threading.Thread (new System.Threading.ThreadStart (this.Upload));
-				command_thread.Name = Mono.Posix.Catalog.GetString ("Uploading Pictures");
+				command_thread.Name = Catalog.GetString ("Uploading Pictures");
 				
-				progress_dialog = new FSpot.ThreadProgressDialog (command_thread, photos.Length);
+				progress_dialog = new FSpot.ThreadProgressDialog (command_thread, items.Length);
 				progress_dialog.Start ();
 
 				// Save these settings for next time
@@ -546,7 +537,7 @@ namespace FSpot {
 					progress_dialog.ProgressText = System.String.Format ("{0} Sent",SizeUtil.ToHumanReadable(args.BytesSent));
 				else
 					progress_dialog.ProgressText = System.String.Format ("{0} of approx. {1}", SizeUtil.ToHumanReadable(sent_bytes + args.BytesSent), SizeUtil.ToHumanReadable(approx_size));
-				progress_dialog.Fraction = ((photo_index - 1) / (double) photos.Length) + (args.BytesSent / (args.BytesTotal * (double) photos.Length));
+				progress_dialog.Fraction = ((photo_index - 1) / (double) items.Length) + (args.BytesSent / (args.BytesTotal * (double) items.Length));
 		}
 
 		private void Upload ()
@@ -567,17 +558,17 @@ namespace FSpot {
 				if (rotate)
 					filters.Add (new OrientationFilter ());
 
-				while (photo_index < photos.Length) {
-					Photo photo = photos [photo_index];
+				while (photo_index < items.Length) {
+					IBrowsableItem item = items[photo_index];
 
 					FileInfo file_info;
 					Console.WriteLine ("uploading {0}", photo_index);
 
 					progress_dialog.Message = String.Format (Catalog.GetString ("Uploading picture \"{0}\" ({1} of {2})"), 
-										 photo.Name, photo_index+1, photos.Length);
+										 item.Name, photo_index+1, items.Length);
 					photo_index++;
 					
-					string orig = photo.DefaultVersionUri.LocalPath;
+					string orig = item.DefaultVersionUri.LocalPath;
 					string final = ImageFile.TempPath(orig, "jpg");
 
 					if (!filters.Convert (orig, final))
@@ -586,11 +577,11 @@ namespace FSpot {
 					file_info = new FileInfo (final);
 
 					if (approx_size == 0) //first image
-						approx_size = file_info.Length * photos.Length;
+						approx_size = file_info.Length * items.Length;
 					else
-						approx_size = sent_bytes * photos.Length / (photo_index - 1);
+						approx_size = sent_bytes * items.Length / (photo_index - 1);
 
-					album.UploadPicture (final, photo.Description);
+					album.UploadPicture (final, item.Description);
 
 					sent_bytes += file_info.Length;
 
@@ -600,18 +591,19 @@ namespace FSpot {
 				
 				progress_dialog.Message = Catalog.GetString ("Done Sending Photos");
 				progress_dialog.Fraction = 1.0;
-				progress_dialog.ProgressText = Mono.Posix.Catalog.GetString ("Upload Complete");
+				progress_dialog.ProgressText = Catalog.GetString ("Upload Complete");
 				progress_dialog.ButtonLabel = Gtk.Stock.Ok;
+
+				if (browser) {
+					GnomeUtil.UrlShow (null, album.Link);
+				}
 			} catch (System.Exception e) {
-				progress_dialog.Message = String.Format (Mono.Posix.Catalog.GetString ("Error Uploading To Gallery: {0}"),
+				progress_dialog.Message = String.Format (Catalog.GetString ("Error Uploading To Gallery: {0}"),
 									 e.Message);
-				progress_dialog.ProgressText = Mono.Posix.Catalog.GetString ("Error");
+				progress_dialog.ProgressText = Catalog.GetString ("Error");
 				System.Console.WriteLine (e);
 			}
 			
-			if (browser) {
-				GnomeUtil.UrlShow (null, album.Link);
-			}
 		}
 
 		private void HandleScaleCheckToggled (object o, EventArgs e)
@@ -627,7 +619,7 @@ namespace FSpot {
 
 			accounts = manager.GetAccounts ();
 			if (accounts == null || accounts.Count == 0) {
-				Gtk.MenuItem item = new Gtk.MenuItem (Mono.Posix.Catalog.GetString ("(No Gallery)"));
+				Gtk.MenuItem item = new Gtk.MenuItem (Catalog.GetString ("(No Gallery)"));
 				menu.Append (item);
 				gallery_optionmenu.Sensitive = false;
 				edit_button.Sensitive = false;
@@ -700,13 +692,11 @@ namespace FSpot {
 				PopulateAlbumOptionMenu (account.Picasa);
 				album_button.Sensitive = false;
 
-				GoogleAccountDialog dialog = new GoogleAccountDialog (this.Dialog, account, false, exc);
-
-				Gtk.ResponseType response = (Gtk.ResponseType) dialog.Dialog.Run ();
+				new GoogleAccountDialog (this.Dialog, account, false, exc);
 				
 				System.Console.WriteLine ("Your google account is locked, you can unlock it by visiting: {0}", CaptchaException.UnlockCaptchaURL);
 
-			} catch (System.Exception ex) {
+			} catch (System.Exception) {
 				System.Console.WriteLine ("Can not connect to Picasa. Bad username ? password ? network connection ?");
 				//System.Console.WriteLine ("{0}",ex);
 				if (selected != null)
@@ -717,12 +707,7 @@ namespace FSpot {
 				status_label.Text = "";
 				album_button.Sensitive = false;
 				
-				GoogleAccountDialog dialog = new GoogleAccountDialog (this.Dialog, account, true, null);
-				Gtk.ResponseType response = (Gtk.ResponseType) dialog.Dialog.Run ();
-
-//				if (response == Gtk.ResponseType.Ok) {
-//					Connect (account);					
-//				}
+				new GoogleAccountDialog (this.Dialog, account, true, null);
 			} 
 		}
 
@@ -748,8 +733,12 @@ namespace FSpot {
 		{
 			PicasaAlbumCollection albums = null;
 			if (picasa != null) {
-				//gallery.FetchAlbumsPrune ();
-				albums = picasa.GetAlbums();
+				try {
+					albums = picasa.GetAlbums();
+				} catch {
+					Console.WriteLine("Can't get the albums");
+					picasa = null;
+				}
 			}
 
 			Gtk.Menu menu = new Gtk.Menu ();
@@ -757,8 +746,8 @@ namespace FSpot {
 			bool disconnected = picasa == null || !account.Connected || albums == null;
 
 			if (disconnected || albums.Count == 0) {
-				string msg = disconnected ? Mono.Posix.Catalog.GetString ("(Not Connected)") 
-					: Mono.Posix.Catalog.GetString ("(No Albums)");
+				string msg = disconnected ? Catalog.GetString ("(Not Connected)") 
+					: Catalog.GetString ("(No Albums)");
 
 				Gtk.MenuItem item = new Gtk.MenuItem (msg);
 				menu.Append (item);
@@ -773,22 +762,14 @@ namespace FSpot {
 				foreach (PicasaAlbum album in albums.AllValues) {
 					System.Text.StringBuilder label_builder = new System.Text.StringBuilder ();
 					
-//					for (int i=0; i < album.Parents.Count; i++) {
-//						label_builder.Append ("  ");
-//					}
 					label_builder.Append (album.Title);
 
 					Gtk.MenuItem item = new Gtk.MenuItem (label_builder.ToString ());
 					((Gtk.Label)item.Child).UseUnderline = false;
 					menu.Append (item);
-			
-				        //AlbumPermission add_permission = album.Perms & AlbumPermission.Add;
-
-//					if (add_permission == 0)
-//						item.Sensitive = false;
 				}
 
-				ok_button.Sensitive = photos.Length > 0;
+				ok_button.Sensitive = items.Length > 0;
 				album_optionmenu.Sensitive = true;
 				album_button.Sensitive = true;
 			}
@@ -799,12 +780,12 @@ namespace FSpot {
 		
 		public void HandleAddGallery (object sender, System.EventArgs args)
 		{
-			gallery_add = new GoogleAccountDialog (this.Dialog);
+			new GoogleAccountDialog (this.Dialog);
 		}
 		
 		public void HandleEditGallery (object sender, System.EventArgs args)
 		{
-			gallery_add = new GoogleAccountDialog (this.Dialog, account, false, null);
+			new GoogleAccountDialog (this.Dialog, account, false, null);
 		}
 
 		public void HandleAddAlbum (object sender, System.EventArgs args)
@@ -812,7 +793,7 @@ namespace FSpot {
 			if (account == null)
 				throw new Exception (Catalog.GetString ("No account selected"));
 				
-			album_add = new GoogleAddAlbum (this, account.Picasa);
+			new GoogleAddAlbum (this, account.Picasa);
 		}
 
 		void LoadPreference (string key)
