@@ -3,6 +3,7 @@ using System.Collections;
 using System.Runtime.InteropServices;
 using System;
 using System.IO;
+using FSpot;
 
 /**
   1        2       3      4         5            6           7          8
@@ -12,6 +13,9 @@ using System.IO;
 8888      8888    8888  8888    88          8888888888  8888888888          88
 88          88      88  88
 88          88  888888  888888
+
+t-l     t-r     b-r     b-l     l-t         r-t         r-b             l-b
+
 **/
 
 public enum PixbufOrientation {
@@ -103,6 +107,7 @@ class PixbufUtils {
 		int max_width;
 		int max_height;
 		PixbufOrientation orientation;
+		int orig_width;
 
 		public AspectLoader (int max_width, int max_height) 
 		{
@@ -165,7 +170,7 @@ class PixbufUtils {
 				using (fs = File.OpenRead (path)) {
 					return Load (fs, orientation);
 				}
-			} catch (Exception e) {
+			} catch (Exception) {
 				System.Console.WriteLine ("Error loading photo {0}", path);
 				return null;
 			} 
@@ -201,6 +206,33 @@ class PixbufUtils {
 		return result;
 	}
 		
+	static public void GetSize (string path, out int width, out int height)
+	{
+		Gdk.PixbufLoader loader = new Gdk.PixbufLoader ();
+		int orig_width = 0;
+		int orig_height = 0;
+		bool done = false;
+
+		loader.SizePrepared += delegate (object obj, SizePreparedArgs args) {
+			orig_width = args.Width;
+			orig_height = args.Height;
+			done = true;
+		};
+		
+		using (Stream stream = File.OpenRead (path)) {
+			byte [] data = new byte [4096];
+			int count;
+
+			while (((count = stream.Read (data, 0, data.Length)) > 0) && loader.Write (data, (ulong)count)) {
+				if (done)
+					break;
+			}
+		}
+		
+		width = orig_width;
+		height = orig_height;
+	}
+
 	static public Pixbuf LoadAtMaxSize (string path, int max_width, int max_height)
 	{
 #if true
@@ -375,7 +407,7 @@ class PixbufUtils {
 	static public Pixbuf LoadFromAssembly (string resource)
 	{
 		try {
-			return new Pixbuf (System.Reflection.Assembly.GetCallingAssembly (), resource);
+			return new Pixbuf (System.Reflection.Assembly.GetEntryAssembly (), resource);
 		} catch {
 			return null;
 		}
@@ -427,10 +459,27 @@ class PixbufUtils {
 			exif_data = new Exif.ExifData ();
 
 		Gdk.Pixbuf image = PixbufUtils.LoadAtMaxSize (orig_path, size, size);
+
 		PixbufUtils.SaveJpeg (image, dest_path, 95, exif_data);
+		image.Dispose ();
 	}
 	
 
+	public static Pixbuf Flatten (Pixbuf pixbuf)
+	{
+		if (!pixbuf.HasAlpha)
+			return null;
+
+		Pixbuf flattened = new Pixbuf (Colorspace.Rgb, false, 8, pixbuf.Width, pixbuf.Height);
+		pixbuf.CompositeColor (flattened, 0, 0, 
+				       pixbuf.Width, pixbuf.Height, 
+				       0, 0, 1, 1, 
+				       InterpType.Bilinear,
+				       255, 0, 0, 2000, 0xffffff, 0xffffff);
+
+		return flattened;
+	}
+
 	[StructLayout(LayoutKind.Sequential)]
 	public unsafe struct FPixbufJpegMarker {
 		public int type;
@@ -443,6 +492,12 @@ class PixbufUtils {
 
 	public static void SaveJpeg (Pixbuf pixbuf, string path, int quality, Exif.ExifData exif_data)
 	{
+		Pixbuf temp = null;
+		if (pixbuf.HasAlpha) {
+			temp = Flatten (pixbuf);
+			pixbuf = temp;
+		}
+
 		// The DCF spec says thumbnails should be 160x120 always
 		Pixbuf thumbnail = ScaleToAspect (pixbuf, 160, 120);
 		byte [] thumb_data = Save (thumbnail, "jpeg", null, null);
@@ -481,6 +536,9 @@ class PixbufUtils {
 			
 		}
 
+		if (temp != null)
+			temp.Dispose ();
+		
 		if (result == false)
 			throw new System.Exception ("Error Saving File");
 	}
@@ -744,26 +802,18 @@ class PixbufUtils {
 						 trect.Width, trect.Height);
 
 		Gdk.Rectangle subarea;
-		while (rect.Y < args.Y + args.Height) {
-			while (rect.X < args.X + args.Width) {
-				rect.Intersect (args, out subarea);
-				Gdk.Rectangle trans = TransformOrientation (src, subarea, orientation);
+		BlockProcessor proc = new BlockProcessor (args, 256);
+		while (proc.Step (out subarea)) {
+			Gdk.Rectangle trans = TransformOrientation (src, subarea, orientation);
+			Gdk.Pixbuf ssub = new Gdk.Pixbuf (src, subarea.X, subarea.Y,
+							  subarea.Width, subarea.Height);
 
-			        Gdk.Pixbuf ssub = new Gdk.Pixbuf (src, subarea.X, subarea.Y,
-								  subarea.Width, subarea.Height);
+			Gdk.Pixbuf tsub = new Gdk.Pixbuf (tmp, 0, 0, trans.Width, trans.Height);
+			CopyWithOrientation (ssub, tsub, orientation);
 
-				Gdk.Pixbuf tsub = new Gdk.Pixbuf (tmp, 0, 0, trans.Width, trans.Height);
-
-				CopyWithOrientation (ssub, tsub, orientation);
-
-				tsub.CopyArea (0, 0, trans.Width, trans.Height, dest, trans.X, trans.Y);
-				
-				ssub.Dispose ();
-				tsub.Dispose ();
-				rect.X += rect.Width;
-			}
-			rect.X = args.X;
-			rect.Y += rect.Height;
+			tsub.CopyArea (0, 0, trans.Width, trans.Height, dest, trans.X, trans.Y);
+			ssub.Dispose ();
+			tsub.Dispose ();
 		}
 
 		tmp.Dispose ();
