@@ -4,11 +4,21 @@ using Cms;
 using System.IO;
 using FSpot.Xmp;
 using System.Collections;
+using System.Reflection;
+
+#if ENABLE_NUNIT
+using NUnit.Framework;
+#endif
 
 namespace FSpot.Png {
 	public class PngFile : ImageFile, SemWeb.StatementSource {
 		PngHeader header;
 
+                // false seems a safe default
+                public bool Distinct {
+                        get { return false; }
+                }
+
 		private PngHeader Header {
 			get {
 				if (header == null) {
@@ -1413,6 +1423,65 @@ namespace FSpot.Png {
 				return base.Date;
 			}
 		}
+		
+#if ENABLE_NUNIT
+		[TestFixture]
+		public class Tests {
+			public Tests ()
+			{
+				Gnome.Vfs.Vfs.Initialize ();
+				Gtk.Application.Init ();
+			}
+
+			[Test]
+			public void Save ()
+			{
+				Gdk.Pixbuf test = new Gdk.Pixbuf (null, "f-spot-32.png");
+				string path = ImageFile.TempPath ("joe.png");
+				test.Save (path, "png");
+				PngFile pimg = new PngFile (path);
+
+				string desc = "this is a png test";
+				string desc2 = "\000xa9 Novell Inc.";
+				pimg.SetDescription (desc);
+				using (Stream stream = File.OpenWrite (path)) {
+					pimg.Save (stream);
+				}
+				PngFile mod = new PngFile (path);
+				Assert.AreEqual (mod.Orientation, PixbufOrientation.TopLeft);
+				Assert.AreEqual (mod.Description, desc);
+				pimg.SetDescription (desc2);
+
+				using (Stream stream = File.OpenWrite (path)) {
+					pimg.Save (stream);
+				}
+				mod = new PngFile (path);
+				Assert.AreEqual (mod.Description, desc2);
+				
+				File.Delete (path);
+			}
+
+			[Test]
+			public void Load ()
+			{
+				string desc = "(c) 2004 Jakub Steiner\n\nCreated with The GIMP";
+				Assembly assembly = System.Reflection.Assembly.GetExecutingAssembly ();
+				string path  = ImageFile.TempPath ("maddy.png");
+				using (Stream output = File.OpenWrite (path)) {
+					using (Stream source = assembly.GetManifestResourceStream ("f-spot-adjust-colors.png")) {
+						byte [] buffer = new byte [256];
+						while (source.Read (buffer, 0, buffer.Length) > 0) {
+							output.Write (buffer, 0, buffer.Length);
+						}
+					}
+				}
+				PngFile pimg = new PngFile (path);
+				Assert.AreEqual (pimg.Description, desc);
+
+				File.Delete (path);
+			}
+		}
+#endif
 
 #if false
 		public class ImageFile {
