@@ -1,6 +1,7 @@
 using Gtk;
+using Gdk;
 using System;
-using Mono.Posix;
+using Mono.Unix;
 
 namespace FSpot {
 	public class SingleView {
@@ -12,6 +13,7 @@ namespace FSpot {
 
 		[Glade.Widget] Gtk.CheckMenuItem side_pane_item;
 		[Glade.Widget] Gtk.CheckMenuItem toolbar_item;
+		[Glade.Widget] Gtk.CheckMenuItem filenames_item;
 		
 		[Glade.Widget] Gtk.MenuItem zoom_in;
 		[Glade.Widget] Gtk.MenuItem zoom_out;
@@ -21,6 +23,8 @@ namespace FSpot {
 
 		[Glade.Widget] Gtk.Scale zoom_scale;
 
+		[Glade.Widget] Label status_label;
+
 		protected Glade.XML xml;
 		private Gtk.Window window;
 		PhotoImageView image_view;
@@ -35,6 +39,8 @@ namespace FSpot {
 
 		FullScreenView fsview;
 
+		private static Gtk.Tooltips toolTips = new Gtk.Tooltips ();
+
 		public SingleView () : this (FSpot.Global.HomeDirectory) {}
 
 
@@ -68,12 +74,23 @@ namespace FSpot {
 			toolbar_hbox.PackStart (toolbar);
 			GtkUtil.MakeToolbarButton (toolbar, "f-spot-rotate-270", new System.EventHandler (HandleRotate270Command));
 			GtkUtil.MakeToolbarButton (toolbar, "f-spot-rotate-90", new System.EventHandler (HandleRotate90Command));
+
 			toolbar.AppendSpace ();
 
+			Widget fs_button = GtkUtil.MakeToolbarButton (toolbar, "f-spot-fullscreen", new System.EventHandler (HandleViewFullscreen));
+			SetTip (fs_button, Catalog.GetString ("View photos fullscreen"));
+			Widget ss_button = GtkUtil.MakeToolbarButton (toolbar, "f-spot-slideshow", new System.EventHandler (HandleViewSlideshow));
+			SetTip (ss_button, Catalog.GetString ("View photos in a slideshow"));
+
 			collection = new UriCollection (uris);
+
+			TargetEntry [] dest_table = { new TargetEntry ("text/uri-list", 0, 0) };
 			
 			directory_view = new IconView (collection);
 			directory_view.Selection.Changed += HandleSelectionChanged;
+			directory_view.DragDataReceived += HandleDragDataReceived;
+			Gtk.Drag.DestSet (directory_view, DestDefaults.All, dest_table, 
+					DragAction.Copy | DragAction.Move); 
 			directory_view.DisplayTags = false;
 			directory_view.DisplayDates = false;
 			directory_scrolled.Add (directory_view);
@@ -84,6 +101,11 @@ namespace FSpot {
 			FSpot.Global.ModifyColors (image_view);
 			FSpot.Global.ModifyColors (image_scrolled);
 			image_view.ZoomChanged += HandleZoomChanged;
+			image_view.Item.Changed += HandleItemChanged;
+			image_view.ButtonPressEvent += HandleImageViewButtonPressEvent;
+			image_view.DragDataReceived += HandleDragDataReceived;
+			Gtk.Drag.DestSet (image_view, DestDefaults.All, dest_table,
+					DragAction.Copy | DragAction.Move); 
 			image_scrolled.Add (image_view);
 			
 			Window.ShowAll ();
@@ -91,7 +113,8 @@ namespace FSpot {
 			zoom_scale.ValueChanged += HandleZoomScaleValueChanged;
 		
 			LoadPreference (Preferences.VIEWER_SHOW_TOOLBAR);
-			
+ 			LoadPreference (Preferences.VIEWER_INTERPOLATION);
+
 			ShowSidebar = collection.Count > 1;
 
 			near_image.SetFromStock ("f-spot-stock_near", Gtk.IconSize.SmallToolbar);
@@ -99,10 +122,13 @@ namespace FSpot {
 
 			slide_delay = new FSpot.Delay (new GLib.IdleHandler (SlideShow));
 
+			LoadPreference (Preferences.VIEWER_SHOW_FILENAMES);
+
 			Preferences.SettingChanged += OnPreferencesChanged;
 			window.DeleteEvent += HandleDeleteEvent;
 			
 			collection.Changed += HandleCollectionChanged;
+			UpdateStatusLabel ();
 			
 			if (collection.Count > 0)
 				directory_view.Selection.Add (0);
@@ -110,7 +136,6 @@ namespace FSpot {
 
 		public void HandleCollectionChanged (IBrowsableCollection collection)
 		{
-			Console.WriteLine ("changed");
 			if (collection.Count > 0) {
 				Console.WriteLine ("Added selection");
 				directory_view.Selection.Add (0);
@@ -118,6 +143,8 @@ namespace FSpot {
 
 			if (collection.Count > 1)
 				ShowSidebar = true;
+
+			UpdateStatusLabel ();
 		}
 
 		public bool ShowSidebar {
@@ -142,6 +169,18 @@ namespace FSpot {
 			}
 		}
 
+		private Uri CurrentUri
+		{
+			get { 
+			 	return this.uri; 
+			}
+			set {
+			 	this.uri = value;
+				collection.Clear ();
+				collection.LoadItems (new Uri[] { this.uri });
+			}
+		}
+
 		void HandleRotate90Command (object sender, System.EventArgs args) 
 		{
 			RotateCommand command = new RotateCommand (this.Window);
@@ -156,18 +195,63 @@ namespace FSpot {
 			if (command.Execute (RotateDirection.Counterclockwise, new IBrowsableItem [] { image_view.Item.Current })) {
 				collection.MarkChanged (image_view.Item.Index);
 			}
+		}		
+
+		void HandleExportToFlickr (object sender, System.EventArgs args)
+		{
+			new FSpot.FlickrExport (new PhotoArray (directory_view.Selection.Items), false);
 		}
-		
+
+		void HandleExportToPicasaweb (object sender, System.EventArgs args)
+		{
+			new FSpot.GoogleExport (new PhotoArray (directory_view.Selection.Items));
+		}
+
+		void HandleExportToGallery (object sender, System.EventArgs args)
+		{
+			new FSpot.GalleryExport (new PhotoArray (directory_view.Selection.Items)); 
+		}
+
+		void HandleExportToFolder (object sender, System.EventArgs args)
+		{
+			new FSpot.FolderExport (new PhotoArray (directory_view.Selection.Items));			
+		}
+
+		void HandleExportToCD (object sender, System.EventArgs args)
+		{
+			new FSpot.CDExport (new PhotoArray (directory_view.Selection.Items)); 
+		}
+
 		private void HandleSelectionChanged (FSpot.IBrowsableCollection selection) 
 		{
-			System.Console.WriteLine ("selection changed");
 			if (selection.Count > 0) {
 				image_view.Item.Index = ((IconView.SelectionCollection)selection).Ids[0];
+				image_view.Reload ();
 				zoom_scale.Value = image_view.NormalizedZoom;
 				if (metadata_dialog != null)
 					metadata_dialog.InfoDisplay.Photo = image_view.Item.Current;
 			}
-			System.Console.WriteLine ("selection changed");
+			UpdateStatusLabel ();
+		}
+
+		private void HandleItemChanged (BrowsablePointer pointer, BrowsablePointerChangedArgs old)
+		{
+			directory_view.FocusCell = pointer.Index;
+			directory_view.Selection.Clear ();
+			if (collection.Count > 0) {
+				directory_view.Selection.Add (directory_view.FocusCell);
+				directory_view.ScrollTo (directory_view.FocusCell);
+			}
+		}
+
+		void HandleSetAsBackgroundCommand (object sender, EventArgs args)
+		{
+			IBrowsableItem current = image_view.Item.Current;
+
+			if (current == null)
+				return;
+
+			Preferences.SetAsBackground (current.DefaultVersionUri.LocalPath);
 		}
 
 		private void HandleViewToolbar (object sender, System.EventArgs args)
@@ -205,6 +289,12 @@ namespace FSpot {
 			metadata_dialog.Destroyed += HandleMetadataDestroyed;
 		}
 
+		private void HandleViewFilenames (object sender, System.EventArgs args)
+		{
+			directory_view.DisplayFilenames = filenames_item.Active; 
+			UpdateStatusLabel ();
+		}
+
 		private void HandleAbout (object sender, System.EventArgs args)
 		{
 			MainWindow.HandleAbout (sender, args);
@@ -216,6 +306,10 @@ namespace FSpot {
 			new SingleView (uri);
 		}
 
+		private void HandlePreferences (object sender, System.EventArgs args)
+		{
+			SingleView.PreferenceDialog.Show ();
+		}
 
 		private void HandleOpenFolder (object sender, System.EventArgs args)
 		{
@@ -244,10 +338,9 @@ namespace FSpot {
 			chooser.SetUri (uri.ToString ());
 			int response = chooser.Run ();
 
-			if ((ResponseType) response == ResponseType.Ok) {
-				uri = new System.Uri (chooser.Uri);
-				//collection. = uri.LocalPath;
-			}
+			if ((ResponseType) response == ResponseType.Ok)
+				CurrentUri = new System.Uri (chooser.Uri);
+			
 
 			chooser.Destroy ();
 		}
@@ -295,6 +388,16 @@ namespace FSpot {
 			image_view.ZoomOut ();
 		}
 
+		public void HandleZoomOut (object sender, Gtk.ButtonPressEventArgs args)
+		{
+			image_view.ZoomOut ();
+		}
+
+		public void HandleZoomIn (object sender, Gtk.ButtonPressEventArgs args)
+		{
+			image_view.ZoomIn ();
+		}
+
 		public void HandleZoomIn (object sender, System.EventArgs args)
 		{
 			image_view.ZoomIn ();
@@ -313,7 +416,23 @@ namespace FSpot {
 			//zoom_in.Sensitive = (zoom_scale.Value != 1.0);
 			//zoom_out.Sensitive = (zoom_scale.Value != 0.0);
 		}
-	
+
+		private void HandleImageViewButtonPressEvent (object sender, ButtonPressEventArgs args)
+		{
+			if (args.Event.Type != EventType.ButtonPress || args.Event.Button != 3)
+			 	return;
+
+			Gtk.Menu popup_menu = new Gtk.Menu ();
+			bool has_item = image_view.Item.Current != null;
+
+			GtkUtil.MakeMenuItem (popup_menu, "f-spot-rotate-270", delegate { HandleRotate270Command(window, null); }, has_item);
+			GtkUtil.MakeMenuItem (popup_menu, "f-spot-rotate-90", delegate { HandleRotate90Command (window, null); }, has_item);
+			GtkUtil.MakeMenuSeparator (popup_menu);
+			GtkUtil.MakeMenuItem (popup_menu, Catalog.GetString ("Set as Background"), HandleSetAsBackgroundCommand, has_item);
+
+			popup_menu.Popup (null, null, null, 0, Gtk.Global.CurrentEventTime);
+		}
+
 		void HandleDeleteEvent (object sender, DeleteEventArgs args)
 		{
 			SavePreferences ();
@@ -321,6 +440,38 @@ namespace FSpot {
 			args.RetVal = true;
 		}
 
+		void HandleDragDataReceived (object sender, DragDataReceivedArgs args) 
+		{
+		
+		switch (args.Info) {
+		case 0:
+			/* 
+			 * If the drop is coming from inside f-spot then we don't want to import 
+			 */
+			if (Gtk.Drag.GetSourceWidget (args.Context) != null)
+				return;
+
+			UriList list = new UriList (args.SelectionData);
+			collection.LoadItems (list.ToArray());
+
+			break;
+		}
+
+		Gtk.Drag.Finish (args.Context, true, false, args.Time);
+		}
+
+		private void UpdateStatusLabel ()
+		{
+			IBrowsableItem item = image_view.Item.Current;
+			System.Text.StringBuilder sb = new System.Text.StringBuilder();
+			if (filenames_item.Active && item != null)
+				sb.Append (item.Name + "  -  ");
+
+			sb.AppendFormat (Catalog.GetPluralString ("{0} Photo", "{0} Photos", collection.Count), collection.Count);
+			status_label.Text = sb.ToString ();
+
+		}
+
 		private void HandleFileClose (object sender, System.EventArgs args)
 		{
 			SavePreferences ();
@@ -341,6 +492,7 @@ namespace FSpot {
 			}
 		
 			Preferences.Set (Preferences.VIEWER_SHOW_TOOLBAR,	toolbar_hbox.Visible);
+			Preferences.Set (Preferences.VIEWER_SHOW_FILENAMES, filenames_item.Active);
 		}
 
 		private void HandleFileOpen (object sender, System.EventArgs args)
@@ -396,6 +548,18 @@ namespace FSpot {
 
 				toolbar_hbox.Visible = (bool) val;
 				break;
+
+			case Preferences.VIEWER_INTERPOLATION:
+				if ((bool) val)
+					image_view.Interpolation = Gdk.InterpType.Bilinear;
+				else
+					image_view.Interpolation = Gdk.InterpType.Nearest;
+				break;
+
+			case Preferences.VIEWER_SHOW_FILENAMES:
+				if (filenames_item.Active != (bool) val)
+					filenames_item.Active = (bool) val;
+				break;
 			}
 		}
 
@@ -404,5 +568,63 @@ namespace FSpot {
 				return window;
 			}
 		}
+
+		public static void SetTip (Widget widget, string tip)
+		{
+			toolTips.SetTip (widget, tip, null);
+		}
+
+		public class PreferenceDialog : GladeDialog {
+			[Glade.Widget] private CheckButton interpolation_check;
+			public PreferenceDialog () : base ("viewer_preferences")
+			{
+				this.LoadPreference (Preferences.VIEWER_INTERPOLATION);
+				Preferences.SettingChanged += OnPreferencesChanged;
+				this.Dialog.Destroyed += HandleDestroyed;
+			}
+
+			void InterpolationToggled (object sender, System.EventArgs args)
+			{
+				Preferences.Set (Preferences.VIEWER_INTERPOLATION, interpolation_check.Active);
+			}
+			
+			static PreferenceDialog prefs;
+			public static void Show ()
+			{
+				if (prefs == null)
+					prefs = new PreferenceDialog ();
+				
+				prefs.Dialog.Present ();
+			}
+
+			void OnPreferencesChanged (object sender, GConf.NotifyEventArgs args)
+			{
+				LoadPreference (args.Key);
+			}
+
+			void HandleClose (object sender, EventArgs args)
+			{
+				this.Dialog.Destroy ();
+			}
+
+			private void HandleDestroyed (object sender, EventArgs args)
+			{
+				prefs = null;
+			}
+
+			void LoadPreference (string key)
+			{
+				object val = Preferences.Get (key);
+
+				if (val == null)
+					return;
+			
+				switch (key) {
+				case Preferences.VIEWER_INTERPOLATION:
+						interpolation_check.Active = (bool) val;
+					break;
+				}
+			}
+		}
 	}
 }
