@@ -1,7 +1,7 @@
 using Gdk;
 using Gnome;
 using Gtk;
-using Mono.Posix;
+using Mono.Unix;
 using Mono.Data.SqliteClient;
 using System.Collections;
 using System.IO;
@@ -274,6 +274,15 @@ public class TagStore : DbStore {
 		return null;
 	}
 
+	public Tag GetTagById (int id)
+	{
+		foreach (Tag t in this.item_cache.Values)
+			if (t.Id == id)
+				return t;
+
+		return null;
+	}
+
 	public Tag [] GetTagsByNameStart (string s)
 	{
 		ArrayList l = new ArrayList ();
@@ -374,10 +383,10 @@ public class TagStore : DbStore {
 
 	private void CreateDefaultTags ()
 	{
-		Tag favorites_tag = CreateTag (RootCategory, Catalog.GetString ("Favorites"));
-		favorites_tag.StockIconName = "f-spot-favorite.png";
-		favorites_tag.SortPriority = -10;
-		Commit (favorites_tag);
+		Category favorites_category = CreateCategory (RootCategory, Catalog.GetString ("Favorites"));
+		favorites_category.StockIconName = "f-spot-favorite.png";
+		favorites_category.SortPriority = -10;
+		Commit (favorites_category);
 
 		Tag hidden_tag = CreateTag (RootCategory, Catalog.GetString ("Hidden"));
 		hidden_tag.StockIconName = "f-spot-hidden.png";
@@ -410,7 +419,7 @@ public class TagStore : DbStore {
 		: base (connection, true)
 	{
 		// The label for the root category is used in new and edit tag dialogs
-		root_category = new Category (null, 0, Mono.Posix.Catalog.GetString ("(None)"));
+		root_category = new Category (null, 0, Catalog.GetString ("(None)"));
 
 		if (! is_new) {
 			LoadAllTags ();
