@@ -376,12 +376,12 @@ namespace FSpot.Tiff {
 			case "Unicode\0":
 				enc = new System.Text.UnicodeEncoding (! little, true);
 				break;
-			case "SJIS\0\0\0\0":
+			case "JIS\0\0\0\0\0":
 				// FIXME this requires mono locale extras
 				try {
-					enc = System.Text.Encoding.GetEncoding ("shift_jis");
+					enc = System.Text.Encoding.GetEncoding ("euc-jp");
 				} catch {
-					System.Console.WriteLine ("missing shift-jis encoding");
+					System.Console.WriteLine ("missing jis0208 encoding");
 					enc = System.Text.Encoding.Default;
 				}
 				break;
@@ -430,6 +430,11 @@ namespace FSpot.Tiff {
 			System.Console.WriteLine ("old = \"{0}\" new = \"{1}\" heading = \"{2}\"", c.Value, description, heading);
 			return data;
 		}
+
+		public override string ToString ()
+		{
+			return String.Format ("({0},charset={1})", Value, Charset);
+		}
 	}
 
 	public struct CFAPattern {
@@ -657,7 +662,7 @@ namespace FSpot.Tiff {
 		OtherSource = 255
 	}
 
-	public enum ColorSpace : ushort {
+	public enum ColorSpace {
 		StandardRGB = 1,  // sRGB
 		AdobeRGB = 2,
 		Uncalibrated = 0xffff
@@ -803,6 +808,11 @@ namespace FSpot.Tiff {
 		private uint directory_offset;
 		public ImageDirectory Directory;
 
+                // false seems a safe default
+                public bool Distinct {
+                        get { return false; }
+                }
+
 		public Header (System.IO.Stream stream)
 		{
 			//using (new Timer ("new Tiff.Header")) {
@@ -922,8 +932,8 @@ namespace FSpot.Tiff {
 					//case TagId.SpatialFrequencyResponse
 				case TagId.ExifCFAPattern:
 					CFAPattern pattern = new CFAPattern (e.RawData, e.IsLittle);
-					Entity empty = new Entity (null);
-					Statement top = new Statement ("", 
+					Entity empty = new BNode ();
+					Statement top = new Statement (MetadataStore.FSpotXMPBase, 
 								       (Entity)MetadataStore.Namespaces.Resolve ("exif:" + e.Id.ToString ()),
 								       empty);
 					
@@ -1103,7 +1113,7 @@ namespace FSpot.Tiff {
 				if (next_directory_offset != 0 && next_directory_offset != orig_position)
 					next_directory = new ImageDirectory (stream, next_directory_offset, this.endian);
 				
-			} catch (System.Exception e) {
+			} catch (System.Exception) {
 				//System.Console.WriteLine ("Error loading directory {0}", e.ToString ());
 				next_directory = null;
 				next_directory_offset = 0;
@@ -1830,6 +1840,11 @@ namespace FSpot.Tiff {
 	public class TiffFile : ImageFile, SemWeb.StatementSource {
 		public Header Header;
 
+                // false seems a safe default
+                public bool Distinct {
+                        get { return false; }
+                }
+
 		public TiffFile (string path) : base (path)
 		{
 			try {
@@ -2074,7 +2089,7 @@ namespace FSpot.Tiff {
 				SubdirectoryEntry sub = (SubdirectoryEntry) Header.Directory.Lookup (TagId.SubIFDs);
 				ImageDirectory jpeg_directory = sub.Directory [0];
 				return LookupJpegSubstream (jpeg_directory);
-			} catch (System.Exception e) {
+			} catch (System.Exception) {
 				return DCRawFile.RawPixbufStream (uri);
 			}
 		}
