@@ -77,8 +77,11 @@ public class UriList : ArrayList {
 			Add (uri);
 		}
 	}
-
-
+	
+	public UriList () : base ()
+	{
+	}
+	
 	private void LoadFromString (string data) {
 		//string [] items = System.Text.RegularExpressions.Regex.Split ("\n", data);
 		string [] items = data.Split ('\n');
@@ -96,7 +99,20 @@ public class UriList : ArrayList {
 				try {
 					uri = new Uri (s);
 				} catch {
+#if true //Workaround to bgo 362016 in gnome-screenshot. Remove this hack when gnome 2.6.18 is widely distributed.
+					if (System.Text.RegularExpressions.Regex.IsMatch (s, "^file:/[^/]")) {
+						try {
+							s = "file:///" + s.Substring(6);
+							uri = new Uri (s);
+							Console.WriteLine ("Converted uri from file:/ to >>{0}<<", s);
+						} catch {
+							continue;
+						}
+					} else
+						continue;
+#else					
 					continue;
+#endif
 				}
 				Add (uri);
 			}
@@ -152,6 +168,16 @@ public class UriList : ArrayList {
 
 	static char[] CharsToQuote = { ';', '?', ':', '@', '&', '=', '$', ',', '#' };
 
+	public static string UriToStringEscaped (Uri uri)
+	{
+		return EscapeString (uri.ToString (), false, true, false);
+	}
+
+	public static string PathToFileUriEscaped (string path)
+	{
+		return UriToStringEscaped (PathToFileUri (path));
+	}
+
 	public static Uri PathToFileUri (string path)
 	{
 		path = Path.GetFullPath (path);
@@ -176,18 +202,24 @@ public class UriList : ArrayList {
 	{	
 		// FIXME this is so lame do real chacking at some point
 		foreach (string str in uris) {
-			Uri uri;
-
-			if (File.Exists (str) || Directory.Exists (str))
-				uri = PathToFileUri (str);
-			else 
-				uri = new Uri (str);
-			
-			Add (uri);
+			AddUnknown (str);
 		}
 	}
 
-	public UriList (string data) {
+	public void AddUnknown (string unknown)
+	{
+		Uri uri;
+		
+		if (File.Exists (unknown) || Directory.Exists (unknown))
+			uri = PathToFileUri (unknown);
+		else 
+			uri = new Uri (unknown);
+		
+		Add (uri);
+	}
+
+	public UriList (string data) 
+	{
 		LoadFromString (data);
 	}
 	
@@ -197,6 +229,26 @@ public class UriList : ArrayList {
 		LoadFromString (System.Text.Encoding.UTF8.GetString (selection.Data));
 	}
 
+	public new Uri [] ToArray ()
+	{
+		return ToArray (typeof (Uri)) as Uri [];
+	}
+	
+	public void Add (string path)
+	{
+		AddUnknown (path);
+	}
+
+	public void Add (Uri uri)
+	{
+		Add ((object)uri);
+	}
+
+	public void Add (FSpot.IBrowsableItem item)
+	{
+		Add (item.DefaultVersionUri);
+	}
+
 	public override string ToString () {
 		StringBuilder list = new StringBuilder ();
 
@@ -228,12 +280,12 @@ public class UriList : ArrayList {
 }
 
 class GtkUtil {
-	public static void MakeMenuItem (Gtk.Menu menu, string l, EventHandler e)
+	public static Gtk.MenuItem MakeMenuItem (Gtk.Menu menu, string l, EventHandler e)
 	{
-		MakeMenuItem (menu, l, e, true);
+		return MakeMenuItem (menu, l, e, true);
 	}
 	
-	public static void MakeMenuItem (Gtk.Menu menu, string l, EventHandler e, bool enabled)
+	public static Gtk.MenuItem MakeMenuItem (Gtk.Menu menu, string l, EventHandler e, bool enabled)
 	{
 		Gtk.MenuItem i;
 		Gtk.StockItem item = Gtk.StockItem.Zero;
@@ -251,9 +303,11 @@ class GtkUtil {
 		
 		menu.Append (i);
 		i.Show ();
+
+        return i;
 	}
 	
-	public static void MakeMenuItem (Gtk.Menu menu, string label, string image_name, EventHandler e, bool enabled)
+	public static Gtk.MenuItem MakeMenuItem (Gtk.Menu menu, string label, string image_name, EventHandler e, bool enabled)
 	{
 		Gtk.ImageMenuItem i = new Gtk.ImageMenuItem (label);
 		i.Activated += e;
@@ -262,9 +316,11 @@ class GtkUtil {
 		
 		menu.Append (i);
 		i.Show ();
+
+        return i;
 	}
 
-	public static void MakeCheckMenuItem (Gtk.Menu menu, string label, EventHandler e, bool enabled, bool active, bool as_radio)
+	public static Gtk.MenuItem MakeCheckMenuItem (Gtk.Menu menu, string label, EventHandler e, bool enabled, bool active, bool as_radio)
 	{
 		Gtk.CheckMenuItem i = new Gtk.CheckMenuItem (label);
 		i.Activated += e;
@@ -274,6 +330,8 @@ class GtkUtil {
 
 		menu.Append(i);
 		i.Show ();
+
+        return i;
 	}
 
 	public static void MakeMenuSeparator (Gtk.Menu menu)
@@ -341,9 +399,33 @@ class GtkUtil {
 		}
 		return null;
 	}
+}
 
-	
-			
+public class SizeUtil {
+	public static string ToHumanReadable (long size)
+	{
+		string tmp_str = "";
+		float tmp_size = size;
+		int k = 0;
+		string[] size_abr = {"bytes", "kB", "MB", "GB", "TB" };
+		
+		while (tmp_size > 700) { //it's easier to read 0.9MB than 932kB
+			tmp_size = tmp_size / 1024;
+				k++;
+		}
+		
+		if (tmp_size < 7)
+			tmp_str = tmp_size.ToString ("0.##");
+		else if (tmp_size < 70)
+			tmp_str = tmp_size.ToString ("##.#");
+		else
+			tmp_str = tmp_size.ToString ("#,###");
+		
+		if (k < size_abr.Length)
+			return tmp_str + " " + size_abr[k];
+		else
+				return size.ToString();
+	}
 }
 
 class GnomeUtil {
@@ -364,8 +446,8 @@ class GnomeUtil {
 	       		System.Console.WriteLine (ge.ToString ());
 	       		HigMessageDialog md = new HigMessageDialog (window, Gtk.DialogFlags.DestroyWithParent, 
 	       			Gtk.MessageType.Error, Gtk.ButtonsType.Ok, 
-	       			Mono.Posix.Catalog.GetString ("There was an error invoking the external handler"),
-	       			String.Format (Mono.Posix.Catalog.GetString ("Received error:\n\"{0}\"\n"), 
+	       			Mono.Unix.Catalog.GetString ("There was an error invoking the external handler"),
+	       			String.Format (Mono.Unix.Catalog.GetString ("Received error:\n\"{0}\"\n"), 
 	       			ge.Message));
 
 	       		md.Run ();
